@@ -15,9 +15,9 @@
  * passwords being leaked to e.g. other system users. Take extra care when
  * the webserver is shared with untrusted users.
  *
- * @copyright &copy; 2000-2009 The SquirrelMail Project Team
+ * @copyright 2000-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: config_default.php 13537 2009-04-13 16:52:57Z jervfors $
+ * @version $Id: config_default.php 14430 2014-01-21 03:19:33Z pdontthink $
  * @package squirrelmail
  * @subpackage config
  */
@@ -284,6 +284,15 @@ $smtp_sitewide_pass = '';
  */
 $imap_auth_mech = 'login';
 
+/**
+ * Show login error from the IMAP server (true) or show
+ * the traditional/generic "Unknown user or password
+ * incorrect" (false)?
+ *
+ * @global boolean $display_imap_login_error
+ */
+$display_imap_login_error = false;
+
 /**
  * IMAP folder delimiter
  *
@@ -675,6 +684,95 @@ $session_name = 'SQMSESSID';
 $config_location_base = '';
 
 
+/**
+ * Secure Cookies
+ *
+ * Only transmit cookies via a secure connection
+ * if the session was started using HTTPS/SSL?
+ *
+ * Highly recommended
+ *
+ * @global bool $only_secure_cookies
+ * @since 1.5.2 and 1.4.16
+ */
+$only_secure_cookies = true;
+
+/**
+ * Secure Forms
+ *
+ * Disable security tokens used to authenticate the
+ * source of user data received by SquirrelMail?
+ *
+ * It is highly discouraged to enable this setting.
+ *
+ * @global bool $disable_security_tokens
+ * @since 1.5.2 and 1.4.20RC1
+ */
+$disable_security_tokens = false;
+
+/**
+ * Check Page Referrer
+ *
+ * Enforces a safety check on page requests by checking
+ * that the referrer is the domain specified by this
+ * setting.  If this setting is "###DOMAIN###", the
+ * current value of the $domain variable will be used
+ * for the check.
+ *
+ * If a browser doesn't send referrer data, this check
+ * will be silently bypassed.
+ *
+ * Examples:
+ * $check_referrer = 'example.com';
+ * $check_referrer = '###DOMAIN###';
+ *
+ * @global string $check_referrer
+ * @since 1.5.2 and 1.4.20RC1
+ */
+$check_referrer = '';
+
+/**
+ * Rendering Mode (quirks/(almost) standards)
+ * 
+ * Control browser rendering mode (affects
+ * the DOCTYPE at the top of all pages):
+ *
+ * "quirks"    = quirks mode
+ * "almost"    = almost standards mode
+ * "standards" = standards mode
+ *
+ * @global string $browser_rendering_mode
+ * @since 1.4.23
+ */
+$browser_rendering_mode = 'quirks';
+
+/**
+ * Security Image Type
+ *
+ * Switches between using a transparent image
+ * and one that states "this image has been
+ * removed for security reasons"
+ *
+ * @global bool $use_transparent_security_image
+ * @since 1.5.2 and 1.4.23
+ */
+$use_transparent_security_image = true;
+
+/**
+ * Check Mail Mechanism (META/(advanced) JavaScript)
+ * 
+ * Determine the mechanism used to refresh the folder
+ * list (when user has enabled such in their preferences)
+ *
+ * "meta"     = META tag
+ * "basic"    = JavaScript (most compatible; slightly fallible)
+ * "advanced" = JavaScript (less compatible; most accurate)
+ *
+ * @global string $check_mail_mechanism
+ * @since 1.4.23
+ */
+$check_mail_mechanism = 'meta';
+
 
 /**
  * Themes
@@ -855,6 +953,12 @@ $theme[50]['NAME'] = 'Techno Blue';
 $theme[51]['PATH'] = SM_PATH . 'themes/turquoise.php';
 $theme[51]['NAME'] = 'Turquoise';
 
+$theme[52]['PATH'] = SM_PATH . 'themes/solarized_light.php';
+$theme[52]['NAME'] = 'Solarized Light';
+
+$theme[53]['PATH'] = SM_PATH . 'themes/solarized_dark.php';
+$theme[53]['NAME'] = 'Solarized Dark';
+
 /**
  * LDAP server(s)
  *   Array of arrays with LDAP server parameters. See
