@@ -5,9 +5,9 @@
  *
  * Address book backend for LDAP server
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: abook_ldap_server.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: abook_ldap_server.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  * @subpackage addressbook
  */
@@ -272,7 +272,8 @@ class abook_ldap_server extends addressbook_backend {
             /* Undo sanitizing of * symbol */
             $expr = str_replace('\2a','*',$expr);
         }
-        $expression = "cn=$expr";
+        $expr = preg_replace('/\*+/', '*', $expr); // LDAP chokes on more than one *
+        $expression = "(|(cn=$expr)(sn=$expr)(givenname=$expr)(mail=$expr))";
 
         /* Make sure connection is there */
         if(!$this->open()) {
@@ -364,15 +365,27 @@ class abook_ldap_server extends addressbook_backend {
     /**
      * List all entries present in LDAP server
      *
-     * If you run a tiny LDAP server and you want the "List All" button
-     * to show EVERYONE, disable first return call and enable the second one.
-     * Remember that maxrows setting might limit list of returned entries.
+     * If you run a small-sized LDAP server and you want the "List all"
+     * button (found on the address book search screen that is accessed
+     * via the "Addresses" button on the compose screen) to show all
+     * addresses in the directory, add the following to config/config_local.php
+     *
+     *    $ldap_abook_allow_listing = TRUE;
+     *
+     * Remember that the "maxrows" configuration setting for the LDAP
+     * server backend might limit list of returned entries.
+     *
+     * NOTE: You should exercise caution enabling the listing of large
+     *       or public LDAP address book backends.
      *
-     * Careful with this -- it could get quite large for big sites.
      * @return array all entries in ldap server
+     *
      */
      function list_addr() {
-         return array();
-         // return $this->search('*');
+         global $ldap_abook_allow_listing;
+         if ($ldap_abook_allow_listing)
+            return $this->search('*');
+         else
+            return array();
      }
 }
