@@ -5,9 +5,9 @@
  *
  * Functions require SM_PATH and support of forms.php functions
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: addressbook.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: addressbook.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  * @subpackage addressbook
  */
@@ -154,7 +154,7 @@ function addressbook_init($showerr = true, $onlylocal = false) {
      * display address book init errors.
      */
     if ($abook_init_error!='' && $showerr) {
-        $abook_init_error = htmlspecialchars($abook_init_error);
+        $abook_init_error = sm_encode_html_special_chars($abook_init_error);
         error_box($abook_init_error,$color);
     }
 
@@ -666,7 +666,7 @@ class addressbook_backend {
         return false;
     }
 
-    function lookup($value, $field) {
+    function lookup($value, $field=SM_ABOOK_FIELD_NICKNAME) {
         $this->set_error('lookup not implemented');
         return false;
     }
