@@ -7,9 +7,9 @@
  * This file is include by src/login.php, src/redirect.php and
  * src/load_prefs.php.
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: constants.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: constants.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  * @since 1.2.0
  */
@@ -60,5 +60,10 @@ define('SM_ABOOK_FIELD_LASTNAME', 2);
 define('SM_ABOOK_FIELD_EMAIL', 3);
 define('SM_ABOOK_FIELD_LABEL', 4);
 
+/* Define constants for script libraries. */
+define('SM_SCRIPT_LIB_REMOTE_REQUEST', 'remote_request.js');
+define('SM_SCRIPT_LIB_RELOAD_PAGE', 'reload_page.js');
+define('SM_SCRIPT_LIB_COMMON', 'common.js');
+
 do_hook('loading_constants');
 
