@@ -21,9 +21,9 @@
  * Configuration of databasename, username and password is done
  * by using conf.pl or the administrator plugin
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: db_prefs.php 13962 2010-07-21 07:05:29Z pdontthink $
+ * @version $Id: db_prefs.php 14440 2014-01-25 02:24:58Z pdontthink $
  * @package squirrelmail
  * @subpackage prefs
  * @since 1.1.3
@@ -161,9 +161,10 @@ class dbPrefs {
     function getKey($user, $key, $default = '') {
         global $prefs_cache;
 
-        $result = do_hook_function('get_pref_override', array($user, $key));
-//FIXME: testing below for !$result means that a plugin cannot fetch its own pref value of 0, '0', '', FALSE, or anything else that evaluates to boolean FALSE.
-        if (!$result) {
+        $result = NULL;
+        $result = do_hook_function('get_pref_override', array($user, $key, $default));
+// FIXME: ideally, we'd have a better way to determine if the return value from the hook above should be respected, even if it is NULL, but this is as good as it gets for now... previously the test was more weak: if (!$result)
+        if (is_null($result)) {
             cachePrefValues($user);
 
             if (isset($prefs_cache[$key])) {
