@@ -6,9 +6,9 @@
  * This contains all messages, including information, error, and just
  * about any other message you can think of.
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: display_messages.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: display_messages.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  */
 
@@ -32,7 +32,7 @@ function error_message($message, $mailbox, $sort, $startMessage, $color) {
     }
     
     $string .= sprintf (_("Click here to return to %s"),
-                  htmlspecialchars(imap_utf7_decode_local($mailbox))).
+                  sm_encode_html_special_chars(imap_utf7_decode_local($mailbox))).
               '</a></td></tr>';
     error_box($string, $color);
 }
