@@ -6,9 +6,9 @@
  * takes a string of unicode entities and converts it to a cp1255 encoded string
  * Unsupported characters are replaced with ?.
  *
- * @copyright 2004-2010 The SquirrelMail Project Team
+ * @copyright 2004-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: cp1255.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: cp1255.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  * @subpackage encode
  */
@@ -22,8 +22,7 @@ function charset_encode_cp1255 ($string) {
    // don't run encoding function, if there is no encoded characters
    if (! preg_match("'&#[0-9]+;'",$string) ) return $string;
 
-    $string=preg_replace("/&#([0-9]+);/e","unicodetocp1255('\\1')",$string);
-    // $string=preg_replace("/&#[xX]([0-9A-F]+);/e","unicodetocp1255(hexdec('\\1'))",$string);
+    $string=preg_replace_callback("/&#([0-9]+);/",'unicodetocp1255',$string);
 
     return $string;
 }
@@ -36,10 +35,11 @@ function charset_encode_cp1255 ($string) {
  * Don't use it or make sure, that functions/encode/cp1255.php is
  * included.
  *
- * @param int $var decimal unicode value
+ * @param array $matches array with first element a decimal unicode value
  * @return string cp1255 character
  */
-function unicodetocp1255($var) {
+function unicodetocp1255($matches) {
+    $var = $matches[1];
 
     $cp1255chars=array('160' => "\xA0",
                        '161' => "\xA1",
