@@ -6,9 +6,9 @@
  * takes a string of unicode entities and converts it to a koi8-r encoded string
  * Unsupported characters are replaced with ?.
  *
- * @copyright 2004-2010 The SquirrelMail Project Team
+ * @copyright 2004-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: koi8_r.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: koi8_r.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  * @subpackage encode
  */
@@ -22,8 +22,7 @@ function charset_encode_koi8_r ($string) {
    // don't run encoding function, if there is no encoded characters
    if (! preg_match("'&#[0-9]+;'",$string) ) return $string;
 
-    $string=preg_replace("/&#([0-9]+);/e","unicodetokoi8r('\\1')",$string);
-    // $string=preg_replace("/&#[xX]([0-9A-F]+);/e","unicodetokoi8r(hexdec('\\1'))",$string);
+    $string=preg_replace_callback("/&#([0-9]+);/",'unicodetokoi8r',$string);
 
     return $string;
 }
@@ -36,10 +35,11 @@ function charset_encode_koi8_r ($string) {
  * Don't use it or make sure, that functions/encode/koi8_r.php is
  * included.
  *
- * @param int $var decimal unicode value
+ * @param array $matches array with first element a decimal unicode value
  * @return string koi8-r character
  */
-function unicodetokoi8r($var) {
+function unicodetokoi8r($matches) {
+    $var = $matches[1];
 
     $koi8rchars=array('160' => "\x9A",
                       '169' => "\xBF",
