@@ -6,9 +6,9 @@
  * takes a string of unicode entities and converts it to a koi8-u encoded string
  * Unsupported characters are replaced with ?.
  *
- * @copyright &copy; 2004-2006 The SquirrelMail Project Team
+ * @copyright 2004-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: koi8_u.php 12932 2008-02-10 16:49:47Z kink $
+ * @version $Id: koi8_u.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  * @subpackage encode
  */
@@ -22,8 +22,7 @@ function charset_encode_koi8_u ($string) {
    // don't run encoding function, if there is no encoded characters
    if (! preg_match("'&#[0-9]+;'",$string) ) return $string;
 
-    $string=preg_replace("/&#([0-9]+);/e","unicodetokoi8u('\\1')",$string);
-    // $string=preg_replace("/&#[xX]([0-9A-F]+);/e","unicodetokoi8u(hexdec('\\1'))",$string);
+    $string=preg_replace_callback("/&#([0-9]+);/",'unicodetokoi8u',$string);
 
     return $string;
 }
@@ -36,10 +35,11 @@ function charset_encode_koi8_u ($string) {
  * Don't use it or make sure, that functions/encode/koi8_u.php is
  * included.
  *
- * @param int $var decimal unicode value
+ * @param array $matches array with first element a decimal unicode value
  * @return string koi8-u character
  */
-function unicodetokoi8u($var) {
+function unicodetokoi8u($matches) {
+    $var = $matches[1];
 
     $koi8uchars=array('160' => "\x9A",
                       '169' => "\xBF",
