@@ -6,9 +6,9 @@
  * takes a string of unicode entities and converts it to a us-ascii encoded string
  * Unsupported characters are replaced with ?.
  *
- * @copyright &copy; 2004-2009 The SquirrelMail Project Team
+ * @copyright 2004-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: us_ascii.php 13549 2009-04-15 22:00:49Z jervfors $
+ * @version $Id: us_ascii.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  * @subpackage encode
  */
@@ -22,8 +22,7 @@ function charset_encode_us_ascii ($string) {
    // don't run encoding function, if there is no encoded characters
    if (! preg_match("'&#[0-9]+;'",$string) ) return $string;
 
-    $string=preg_replace("/&#([0-9]+);/e","unicodetousascii('\\1')",$string);
-    // $string=preg_replace("/&#[xX]([0-9A-F]+);/e","unicodetousascii(hexdec('\\1'))",$string);
+    $string=preg_replace_callback("/&#([0-9]+);/",'unicodetousascii',$string);
 
     return $string;
 }
@@ -36,10 +35,11 @@ function charset_encode_us_ascii ($string) {
  * Don't use it or make sure, that functions/encode/us_ascii.php is
  * included.
  *
- * @param int $var decimal unicode value
+ * @param array $matches array with first element a decimal unicode value
  * @return string us-ascii character
  */
-function unicodetousascii($var) {
+function unicodetousascii($matches) {
+    $var = $matches[1];
 
     if ($var < 128) {
         $ret = chr ($var);
