@@ -5,9 +5,9 @@
  *
  * This contains functions for manipulating user preferences in files
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: file_prefs.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: file_prefs.php 14440 2014-01-25 02:24:58Z pdontthink $
  * @package squirrelmail
  * @subpackage prefs
  * @since 1.2.5
@@ -89,9 +89,10 @@ function cachePrefValues($data_dir, $username) {
 function getPref($data_dir, $username, $string, $default = '') {
     global $prefs_cache;
 
-    $result = do_hook_function('get_pref_override',array($username, $string));
-//FIXME: testing below for !$result means that a plugin cannot fetch its own pref value of 0, '0', '', FALSE, or anything else that evaluates to boolean FALSE.
-    if (!$result) {
+    $result = NULL;
+    $result = do_hook_function('get_pref_override',array($username, $string, $default, $data_dir));
+// FIXME: ideally, we'd have a better way to determine if the return value from the hook above should be respected, even if it is NULL, but this is as good as it gets for now... previously the test was more weak: if (!$result)
+    if (is_null($result)) {
         cachePrefValues($data_dir, $username);
         if (isset($prefs_cache[$string])) {
             $result = $prefs_cache[$string];
