@@ -9,9 +9,9 @@
  * @link http://www.section508.gov/ Section 508
  * @link http://www.w3.org/WAI/ Web Accessibility Initiative (WAI)
  * @link http://www.w3.org/TR/html4/ W3.org HTML 4.01 form specs
- * @copyright 2004-2010 The SquirrelMail Project Team
+ * @copyright 2004-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: forms.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: forms.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  * @subpackage forms
  * @since 1.4.3 and 1.5.1
@@ -23,9 +23,10 @@
  */
 function addInputField($type, $name = null, $value = null, $attributes = '') {
     return '<input type="'.$type.'"'.
-        ($name  !== null ? ' name="'.htmlspecialchars($name).'"'   : '').
-        ($value !== null ? ' value="'.htmlspecialchars($value).'"' : '').
-        $attributes . " />\n";
+        ($name !== null ? ' name="'.sm_encode_html_special_chars($name).'"' : '').
+        ($name !== null && strpos($attributes, 'id="') === FALSE ? ' id="'.sm_encode_html_special_chars(strtr($name, '[]', '__')).'"' : '').
+        ($value !== null ? ' value="'.sm_encode_html_special_chars($value).'"' : '').
+        ' ' . $attributes . " />\n";
 }
 
 /**
@@ -89,16 +90,18 @@ function addSelect($name, $values, $default = null, $usekeys = false)
     if(count($values) == 1) {
         $k = key($values); $v = array_pop($values);
         return addHidden($name, ($usekeys ? $k:$v)).
-            htmlspecialchars($v) . "\n";
+            sm_encode_html_special_chars($v) . "\n";
     }
 
-    $ret = '<select name="'.htmlspecialchars($name) . "\">\n";
+    $ret = '<select name="'.sm_encode_html_special_chars($name)
+         . ($name !== null ? '" id="'.sm_encode_html_special_chars(strtr($name, '[]', '__')).'"' : '"')
+         . ">\n";
     foreach ($values as $k => $v) {
         if(!$usekeys) $k = $v;
         $ret .= '<option value="' .
-            htmlspecialchars( $k ) . '"' .
+            sm_encode_html_special_chars( $k ) . '"' .
             (($default == $k) ? ' selected="selected"' : '') .
-            '>' . htmlspecialchars($v) ."</option>\n";
+            '>' . sm_encode_html_special_chars($v) ."</option>\n";
     }
     $ret .= "</select>\n";
 
@@ -123,9 +126,10 @@ function addReset($value) {
  * Textarea form element.
  */
 function addTextArea($name, $text = '', $cols = 40, $rows = 10, $attr = '') {
-    return '<textarea name="'.htmlspecialchars($name).'" '.
+    return '<textarea name="'.sm_encode_html_special_chars($name).'" '.
+        ($name !== null && strpos($attr, 'id="') === FALSE ? 'id="'.sm_encode_html_special_chars(strtr($name, '[]', '__')).'" ' : ' ').
         'rows="'.(int)$rows .'" cols="'.(int)$cols.'" '.
-        $attr . '>'.htmlspecialchars($text) ."</textarea>\n";
+        $attr . '>'.sm_encode_html_special_chars($text) ."</textarea>\n";
 }
 
 /**
@@ -156,7 +160,7 @@ function addForm($action, $method = 'post', $name = '', $enctype = '', $charset
         $enctype = ' enctype="'.$enctype.'"';
     }
     if($charset) {
-        $charset = ' accept-charset="'.htmlspecialchars($charset).'"';
+        $charset = ' accept-charset="'.sm_encode_html_special_chars($charset).'"';
     }
 
     $form_string = '<form action="'. $action .'" method="'. $method .'"'.
