@@ -5,9 +5,9 @@
  *
  * This implements all functions that do general IMAP functions.
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: imap_general.php 13972 2010-07-23 03:18:42Z pdontthink $
+ * @version $Id: imap_general.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package squirrelmail
  * @subpackage imap
  */
@@ -79,23 +79,23 @@ function sqimap_run_command ($imap_stream, $query, $handle_errors, &$response,
 function sqimap_run_literal_command($imap_stream, $query, $handle_errors, &$response, &$message, $unique_id = false) {
     if ($imap_stream) {
         $sid = sqimap_session_id($unique_id);
-        $command = sprintf("%s {%d}\r\n", $query['command'], strlen($query['literal_args'][0]));
+        $command = sprintf("%s {%d}\r\n", $query['commands'][0], strlen($query['literal_args'][0]));
         fputs($imap_stream, $sid . ' ' . $command);
 
         // TODO: Put in error handling here //
-        $read = sqimap_read_data($imap_stream, $sid, $handle_errors, $response, $message, $query['command']);
+        $read = sqimap_read_data($imap_stream, $sid, $handle_errors, $response, $message, $query['commands'][0]);
         
         $i = 0;
         $cnt = count($query['literal_args']);
         while( $i < $cnt ) {
         	if (($cnt > 1) && ($i < ($cnt - 1))) {
-				$command = sprintf("%s {%d}\r\n", $query['literal_args'][$i], strlen($query['literal_args'][$i+1]));
+				$command = sprintf("%s%s {%d}\r\n", $query['literal_args'][$i], (!empty($query['commands'][$i+1]) ? ' ' . $query['commands'][$i+1] : ''), strlen($query['literal_args'][$i+1]));
 			} else {
 				$command = sprintf("%s\r\n", $query['literal_args'][$i]);
 			}
         	
 			fputs($imap_stream, $command);
-	        $read = sqimap_read_data($imap_stream, $sid, $handle_errors, $response, $message, $query['command']);
+	        $read = sqimap_read_data($imap_stream, $sid, $handle_errors, $response, $message, $query['commands'][0]);
 
 	        $i++;
 	        
@@ -367,7 +367,7 @@ function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
         $cmd = explode(' ',$query);
         $cmd = strtolower($cmd[0]);
         if ($query != '' &&  $cmd != 'login') {
-            $string .= ("Query:") . ' '. htmlspecialchars($query)
+            $string .= ("Query:") . ' '. sm_encode_html_special_chars($query)
             . '<br />' . "</font><br />\n";
         }
         error_box($string,$color);
@@ -399,9 +399,9 @@ function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
                 _("ERROR: Could not complete request.") .
                 "</b><br />\n" .
                 _("Query:") . ' ' .
-                htmlspecialchars($query) . '<br />' .
+                sm_encode_html_special_chars($query) . '<br />' .
                 _("Reason Given:") . ' ' .
-                htmlspecialchars($message) . "</font><br />\n";
+                sm_encode_html_special_chars($message) . "</font><br />\n";
             error_box($string,$color);
             echo '</body></html>';
             exit;
@@ -414,9 +414,9 @@ function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
             _("ERROR: Bad or malformed request.") .
             "</b><br />\n" .
             _("Query:") . ' '.
-            htmlspecialchars($query) . '<br />' .
+            sm_encode_html_special_chars($query) . '<br />' .
             _("Server responded:") . ' ' .
-            htmlspecialchars($message) . "</font><br />\n";
+            sm_encode_html_special_chars($message) . "</font><br />\n";
         error_box($string,$color);
         echo '</body></html>';
         exit;
@@ -427,9 +427,9 @@ function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
             _("ERROR: IMAP server closed the connection.") .
             "</b><br />\n" .
             _("Query:") . ' '.
-            htmlspecialchars($query) . '<br />' .
+            sm_encode_html_special_chars($query) . '<br />' .
             _("Server responded:") . ' ' .
-            htmlspecialchars($message) . "</font><br />\n";
+            sm_encode_html_special_chars($message) . "</font><br />\n";
         error_box($string,$color);
         echo '</body></html>';
         exit;
@@ -440,9 +440,9 @@ function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
             _("ERROR: Unknown IMAP response.") .
             "</b><br />\n" .
             _("Query:") . ' '.
-            htmlspecialchars($query) . '<br />' .
+            sm_encode_html_special_chars($query) . '<br />' .
             _("Server responded:") . ' ' .
-            htmlspecialchars($message) . "</font><br />\n";
+            sm_encode_html_special_chars($message) . "</font><br />\n";
         error_box($string,$color);
        /* the error is displayed but because we don't know the reponse we
           return the result anyway */
@@ -463,13 +463,14 @@ function sqimap_read_data ($imap_stream, $tag_uid, $handle_errors,
        and merge the $res array IF they are seperated and
        IF it was a FETCH response. */
 
-//    if (isset($res[1]) && is_array($res[1]) && isset($res[1][0])
-//        && preg_match('/^\* \d+ FETCH/', $res[1][0])) {
-//        $result = array();
-//        foreach($res as $index=>$value) {
-//            $result = array_merge($result, $res["$index"]);
-//        }
-//    }
+    if (isset($res[1]) && is_array($res[1]) && isset($res[1][0])
+        && preg_match('/^\* \d+ FETCH/', $res[1][0])) {
+        $result = array();
+        foreach($res as $index=>$value) {
+            $result = array_merge($result, $res["$index"]);
+        }
+        return $result;
+    }
 
     return $res[0];
 }
@@ -478,8 +479,32 @@ function sqimap_read_data ($imap_stream, $tag_uid, $handle_errors,
  * Logs the user into the IMAP server.  If $hide is set, no error messages
  * will be displayed.  This function returns the IMAP connection handle.
  */
-function sqimap_login ($username, $password, $imap_server_address, $imap_port, $hide) {
-    global $color, $squirrelmail_language, $onetimepad, $use_imap_tls, $imap_auth_mech;
+function sqimap_login ($username, $password, $imap_server_address, $imap_port, $hide, $stream_options=array()) {
+    global $color, $squirrelmail_language, $onetimepad, $use_imap_tls, $imap_auth_mech,
+           $sqimap_capabilities, $display_imap_login_error;
+
+    // Note/TODO: This hack grabs the $authz argument from the session
+    $authz = '';
+    global $authz;
+    sqgetglobalvar('authz' , $authz , SQ_SESSION);
+
+    if(!empty($authz)) {
+        /* authz plugin - specific:
+         * Get proxy login parameters from authz plugin configuration. If they
+         * exist, they will override the current ones.
+         * This is useful if we want to use different SASL authentication mechanism
+         * and/or different TLS settings for proxy logins. */
+        global $authz_imap_auth_mech, $authz_use_imap_tls, $authz_imapPort_tls;
+        $imap_auth_mech = !empty($authz_imap_auth_mech) ? strtolower($authz_imap_auth_mech) : $imap_auth_mech;
+        $use_imap_tls = !empty($authz_use_imap_tls)? $authz_use_imap_tls : $use_imap_tls;
+        $imap_port = !empty($authz_use_imap_tls)? $authz_imapPort_tls : $imap_port;
+
+        if($imap_auth_mech == 'login' || $imap_auth_mech == 'cram-md5') {
+            logout_error("Misconfigured Plugin (authz or equivalent):<br/>".
+            "The LOGIN and CRAM-MD5 authentication mechanisms cannot be used when attempting proxy login.");
+            exit;
+        }
+    }
 
     if (!isset($onetimepad) || empty($onetimepad)) {
         sqgetglobalvar('onetimepad' , $onetimepad , SQ_SESSION );
@@ -487,12 +512,25 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
     $imap_server_address = sqimap_get_user_server($imap_server_address, $username);
         $host=$imap_server_address;
 
-        if (($use_imap_tls == true) and (check_php_version(4,3)) and (extension_loaded('openssl'))) {
-          /* Use TLS by prefixing "tls://" to the hostname */
-          $imap_server_address = 'tls://' . $imap_server_address;
+    // NB: Using "ssl://" ensures the highest possible TLS version
+    // will be negotiated with the server (whereas "tls://" only
+    // uses TLS version 1.0)
+    //
+    if (($use_imap_tls == true) and (check_php_version(4,3)) and (extension_loaded('openssl'))) {
+        if (function_exists('stream_socket_client')) {
+            $server_address = 'ssl://' . $imap_server_address . ':' . $imap_port;
+            $ssl_context = @stream_context_create($stream_options);
+            $connect_timeout = ini_get('default_socket_timeout');
+            // null timeout is broken
+            if ($connect_timeout == 0)
+                $connect_timeout = 15;
+            $imap_stream = @stream_socket_client($server_address, $error_number, $error_string, $connect_timeout, STREAM_CLIENT_CONNECT, $ssl_context);
+        } else {
+            $imap_stream = @fsockopen('ssl://' . $imap_server_address, $imap_port, $error_number, $error_string, 15);
         }
-
-    $imap_stream = @fsockopen($imap_server_address, $imap_port, $error_number, $error_string, 15);
+    } else {
+        $imap_stream = @fsockopen($imap_server_address, $imap_port, $error_number, $error_string, 15);
+    }
 
     /* Do some error correction */
     if (!$imap_stream) {
@@ -511,6 +549,10 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
     /* Decrypt the password */
     $password = OneTimePadDecrypt($password, $onetimepad);
 
+    if (!isset($sqimap_capabilities)) {
+        sqgetglobalvar('sqimap_capabilities' , $sqimap_capabilities , SQ_SESSION );
+    }
+
     if (($imap_auth_mech == 'cram-md5') OR ($imap_auth_mech == 'digest-md5')) {
         // We're using some sort of authentication OTHER than plain or login
         $tag=sqimap_session_id(false);
@@ -527,7 +569,7 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
             // Got a challenge back
             $challenge=$response[1];
             if ($imap_auth_mech == 'digest-md5') {
-                $reply = digest_md5_response($username,$password,$challenge,'imap',$host);
+                $reply = digest_md5_response($username,$password,$challenge,'imap',$host,$authz);
             } elseif ($imap_auth_mech == 'cram-md5') {
                 $reply = cram_md5_response($username,$password,$challenge);
             }
@@ -564,8 +606,9 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
         } else {
             // Original IMAP login code
             if(sq_is8bit($username) || sq_is8bit($password)) {
-                $query['command'] = 'LOGIN';
+                $query['commands'][0] = 'LOGIN';
                 $query['literal_args'][0] = $username;
+                $query['commands'][1] = '';
                 $query['literal_args'][1] = $password;
                 $read = sqimap_run_literal_command($imap_stream, $query, false, $response, $message);
             } else {
@@ -575,9 +618,45 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
             }
         }
     } elseif ($imap_auth_mech == 'plain') {
-        /* Replace this with SASL PLAIN if it ever gets implemented */
-        $response="BAD";
-        $message='SquirrelMail does not support SASL PLAIN yet. Rerun conf.pl and use login instead.';
+        /***
+         * SASL PLAIN, RFC 4616 (updates 2595)
+         *
+         * The mechanism consists of a single message, a string of [UTF-8]
+         * encoded [Unicode] characters, from the client to the server.  The
+         * client presents the authorization identity (identity to act as),
+         * followed by a NUL (U+0000) character, followed by the authentication
+         * identity (identity whose password will be used), followed by a NUL
+         * (U+0000) character, followed by the clear-text password.  As with
+         * other SASL mechanisms, the client does not provide an authorization
+         * identity when it wishes the server to derive an identity from the
+         * credentials and use that as the authorization identity.
+         */
+        $tag=sqimap_session_id(false);
+        $sasl = (isset($sqimap_capabilities['SASL-IR']) && $sqimap_capabilities['SASL-IR']) ? true : false;
+        if(!empty($authz)) {
+            $auth = base64_encode("$username\0$authz\0$password");
+        } else {
+            $auth = base64_encode("$username\0$username\0$password");
+        }
+        if ($sasl) {
+            // IMAP Extension for SASL Initial Client Response
+            // <draft-siemborski-imap-sasl-initial-response-01b.txt>
+            $query = $tag . " AUTHENTICATE PLAIN $auth\r\n";
+            fputs($imap_stream, $query);
+            $read = sqimap_fgets($imap_stream);
+        } else {
+            $query = $tag . " AUTHENTICATE PLAIN\r\n";
+            fputs($imap_stream, $query);
+            $read=sqimap_fgets($imap_stream);
+            if (substr($read,0,1) == '+') { // OK so far..
+                fputs($imap_stream, "$auth\r\n");
+                $read = sqimap_fgets($imap_stream);
+            }
+        }
+        $results=explode(" ",$read,3);
+        $response=$results[1];
+        $message=$results[2];
+
     } else {
         $response="BAD";
         $message="Internal SquirrelMail error - unknown IMAP authentication method chosen.  Please contact the developers.";
@@ -588,7 +667,7 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
         if (!$hide) {
             if ($response != 'NO') {
                 /* "BAD" and anything else gets reported here. */
-                $message = htmlspecialchars($message);
+                $message = sm_encode_html_special_chars($message);
                 set_up_language($squirrelmail_language, true);
                 require_once(SM_PATH . 'functions/display_messages.php');
                 if ($response == 'BAD') {
@@ -599,7 +678,7 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
                 if (isset($read) && is_array($read)) {
                     $string .= '<br />' . _("Read data:") . "<br />\n";
                     foreach ($read as $line) {
-                        $string .= htmlspecialchars($line) . "<br />\n";
+                        $string .= sm_encode_html_special_chars($line) . "<br />\n";
                     }
                 }
                 error_box($string,$color);
@@ -621,7 +700,29 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
                 sqsession_destroy();
                 /* terminate the session nicely */
                 sqimap_logout($imap_stream);
-                logout_error( _("Unknown user or password incorrect.") );
+
+                // determine what error message to show to the user
+                //
+                $fail_msg = _("Unknown user or password incorrect.");
+                if ($display_imap_login_error) {
+                    // See if there is an error message from the server
+                    // Skip any rfc5530 response code: '[something]' at the
+                    // start of the message
+                    if (!empty($message)
+                     && $message{0} == '['
+                     && ($end = strstr($message, ']'))
+                     && $end != ']') {
+                        $message = substr($end, 1);
+                    }
+                    // Remove surrounding spaces and if there
+                    // is anything left, display that as the
+                    // error message:
+                    $message = trim($message);
+                    if (strlen($message))
+                        $fail_msg = _($message);
+                }
+
+                logout_error($fail_msg);
                 exit;
             }
         } else {
@@ -688,7 +789,7 @@ function sqimap_get_delimiter ($imap_stream = false) {
 
     /* Do some caching here */
     if (!$sqimap_delimiter) {
-        if (sqimap_capability($imap_stream, 'NAMESPACE')) {
+        if (sqimap_capability($imap_stream, 'NAMESPACE')
             /*
              * According to something that I can't find, this is supposed to work on all systems
              * OS: This won't work in Courier IMAP.
@@ -696,22 +797,21 @@ function sqimap_get_delimiter ($imap_stream = false) {
              * OS: * NAMESPACE (PERSONAL NAMESPACES) (OTHER_USERS NAMESPACE) (SHARED NAMESPACES)
              * OS: We want to lookup all personal NAMESPACES...
              */
-            $read = sqimap_run_command($imap_stream, 'NAMESPACE', true, $a, $b);
-            if (preg_match('/\* NAMESPACE +(\( *\(.+\) *\)|NIL) +(\( *\(.+\) *\)|NIL) +(\( *\(.+\) *\)|NIL)/i', $read[0], $data)) {
-                if (preg_match('/^\( *\((.*)\) *\)/', $data[1], $data2)) {
-                    $pn = $data2[1];
-                }
-                $pna = explode(')(', $pn);
-                while (list($k, $v) = each($pna)) {
-                    $lst = explode('"', $v);
-                    if (isset($lst[3])) {
-                        $pn[$lst[1]] = $lst[3];
-                    } else {
-                        $pn[$lst[1]] = '';
-                    }
+         && ($read = sqimap_run_command($imap_stream, 'NAMESPACE', true, $a, $b))
+         && preg_match('/\* NAMESPACE +(\( *\(.+\) *\)|NIL) +(\( *\(.+\) *\)|NIL) +(\( *\(.+\) *\)|NIL)/i', $read[0], $data)
+         && preg_match('/^\( *\((.*)\) *\)/', $data[1], $data2)) {
+            $pn = $data2[1];
+            $pna = explode(')(', $pn);
+            $delnew = array();
+            while (list($k, $v) = each($pna)) {
+                $lst = explode('"', $v);
+                if (isset($lst[3])) {
+                    $delnew[$lst[1]] = $lst[3];
+                } else {
+                    $delnew[$lst[1]] = '';
                 }
             }
-            $sqimap_delimiter = $pn[0];
+            $sqimap_delimiter = array_shift($delnew);
         } else {
             fputs ($imap_stream, ". LIST \"INBOX\" \"\"\r\n");
             $read = sqimap_read_data($imap_stream, '.', true, $a, $b);
