@@ -5,9 +5,9 @@
  *
  * This implements all functions that manipulate mailboxes
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: imap_mailbox.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: imap_mailbox.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  * @subpackage imap
  */
@@ -98,8 +98,16 @@ function isBoxBelow( $subbox, $parentbox ) {
  * Defines special mailboxes: given a mailbox name, it checks if this is a
  * "special" one: INBOX, Trash, Sent or Draft.
  *
- * Since 1.2.5 function includes special_mailbox hook.<br>
+ * Since 1.2.5 function includes special_mailbox hook.
+ *
  * Since 1.4.3 hook supports more than one plugin.
+ *
+//FIXME: make $subfolders_of_inbox_are_special a configuration setting in conf.pl and config.php
+ * Since 1.4.22/1.5.2, the administrator can add
+ * $subfolders_of_inbox_are_special = TRUE;
+ * to config/config_local.php and all subfolders
+ * of the INBOX will be treated as special.
+ *
  * @param string $box mailbox name
  * @param boolean $include_subs (since 1.5.2 and 1.4.9) if true, subfolders of 
  *  system folders are special. if false, subfolders are not special mailboxes 
@@ -108,7 +116,9 @@ function isBoxBelow( $subbox, $parentbox ) {
  * @since 1.2.3
  */
 function isSpecialMailbox($box,$include_subs=true) {
-    $ret = ( (strtolower($box) == 'inbox') ||
+    global $subfolders_of_inbox_are_special;
+    $ret = ( ($subfolders_of_inbox_are_special && isInboxMailbox($box,$include_subs)) ||
+             (!$subfolders_of_inbox_are_special && strtolower($box) == 'inbox') ||
              isTrashMailbox($box,$include_subs) || 
              isSentMailbox($box,$include_subs) || 
              isDraftMailbox($box,$include_subs) );
@@ -119,6 +129,24 @@ function isSpecialMailbox($box,$include_subs=true) {
     return $ret;
 }
 
+/**
+ * Detects if mailbox is the Inbox folder or subfolder of the Inbox
+ *
+ * @param string $box The mailbox name to test
+ * @param boolean $include_subs If true, subfolders of system folders
+ *                              are special.  If false, subfolders are
+ *                              not special mailboxes.
+ *
+ * @return boolean Whether this is the Inbox or a child thereof.
+ *
+ * @since 1.4.22
+ */
+function isInboxMailbox($box, $include_subs=TRUE) {
+   return ((strtolower($box) == 'inbox')
+        || ($include_subs && isBoxBelow(strtolower($box), 'inbox')));
+}
+
+
 /**
  * Detects if mailbox is a Trash folder or subfolder of Trash
  * @param string $box mailbox name
@@ -226,7 +254,7 @@ function sqimap_mailbox_select ($imap_stream, $mailbox) {
     if (strstr($mailbox, '../') || substr($mailbox, 0, 1) == '/') {
         global $color;
         include_once(SM_PATH . 'functions/display_messages.php');
-        error_box(sprintf(_("Invalid mailbox name: %s"),htmlspecialchars($mailbox)),$color);
+        error_box(sprintf(_("Invalid mailbox name: %s"),sm_encode_html_special_chars($mailbox)),$color);
         sqimap_logout($imap_stream);
         die('</body></html>');
     }
@@ -527,16 +555,16 @@ function sqimap_mailbox_option_list($imap_stream, $show_selected = 0, $folder_sk
                     $box2 = $boxes_part['formatted'];
                     break;
                   default:  /* default, long names, style = 0 */
-                    $box2 = str_replace(' ', '&nbsp;', htmlspecialchars(imap_utf7_decode_local($boxes_part['unformatted-disp'])));
+                    $box2 = str_replace(' ', '&nbsp;', sm_encode_html_special_chars(imap_utf7_decode_local($boxes_part['unformatted-disp'])));
                     break;
                 }
             }
             $box2 = str_replace(array('<','>'), array('&lt;','&gt;') , $box2);
 
             if ($show_selected != 0 && in_array($lowerbox, $show_selected) ) {
-                $mbox_options .= '<option value="' . htmlspecialchars($box) .'" selected="selected">'.$box2.'</option>' . "\n";
+                $mbox_options .= '<option value="' . sm_encode_html_special_chars($box) .'" selected="selected">'.$box2.'</option>' . "\n";
             } else {
-                $mbox_options .= '<option value="' . htmlspecialchars($box) .'">'.$box2.'</option>' . "\n";
+                $mbox_options .= '<option value="' . sm_encode_html_special_chars($box) .'">'.$box2.'</option>' . "\n";
             }
         }
     }
@@ -567,7 +595,7 @@ function mailtree_sort(&$lsub) {
 
 
 function sqimap_mailbox_list($imap_stream, $force=false) {
-    global $default_folder_prefix;
+    global $default_folder_prefix, $default_sub_of_inbox;
 
     if (!sqgetGlobalVar('boxesnew',$boxesnew,SQ_SESSION) || $force) {
         global $data_dir, $username, $list_special_folders_first,
@@ -622,31 +650,34 @@ function sqimap_mailbox_list($imap_stream, $force=false) {
            * Note: according RFC2060 an imap server may provide \NoSelect flags in the LSUB response.
            * in other words, we cannot rely on it.
          */
-        $sorted_list_ary = array();
-        for ($i=0; $i < count($sorted_lsub_ary); $i++) {
-            if (substr($sorted_lsub_ary[$i], -1) == $delimiter) {
-                $mbx = substr($sorted_lsub_ary[$i], 0, strlen($sorted_lsub_ary[$i])-1);
-            }
-            else {
-                $mbx = $sorted_lsub_ary[$i];
-            }
-
-            $read = sqimap_run_command ($imap_stream, "LIST \"\" \"$mbx\"",
+        if ($noselect_fix_enable) {
+            $list_args = "LIST \"$folder_prefix\" \"*%\"";
+        } else {
+            $list_args = "LIST \"$folder_prefix\" \"*\"";
+        }
+        /* LIST array */
+        $list_ary = sqimap_run_command ($imap_stream, $list_args,
                                         true, $response, $message);
-
-            /* Another workaround for literals */
-
-            if (isset($read[1]) && substr($read[1],-3) == "}\r\n") {
+        $sorted_list_ary = array();
+        for ($i = 0, $cnt = count($list_ary);$i < $cnt; $i++) {
+            /*
+             * Workaround for mailboxes returned as literal
+             * Doesn't work if the mailbox name is multiple lines
+             * (larger then fgets buffer)
+             */
+            if (isset($list_ary[$i + 1]) && substr($list_ary[$i],-3) == "}\r\n") {
                 if (preg_match('/^(\* [A-Z]+.*)\{[0-9]+\}([ \n\r\t]*)$/',
-                     $read[0], $regs)) {
-                    $read[0] = $regs[1] . '"' . addslashes(trim($read[1])) . '"' . $regs[2];
+                     $list_ary[$i], $regs)) {
+                        $i++;
+                        $list_ary[$i] = $regs[1] . '"' . addslashes(trim($list_ary[$i])) . '"' . $regs[2];
                 }
             }
+            $temp_mailbox_name = find_mailbox_name($list_ary[$i]);
 
-            if (isset($read[0])) {
-                $sorted_list_ary[$i] = $read[0];
-            } else {
-                $sorted_list_ary[$i] = '';
+            // is_numeric() because before PHP 4.2.0, bad return
+            // value is NULL; whereas in newer versions, it's FALSE
+            if (is_numeric($key = array_search($temp_mailbox_name, $sorted_lsub_ary))) {
+                $sorted_list_ary[$key] = $list_ary[$i];
             }
         }
 
@@ -685,6 +716,22 @@ function sqimap_mailbox_list($imap_stream, $force=false) {
             }
         }
 
+        /* 
+         * For systems where folders might be either under the INBOX or
+         * at the top-level (Dovecot, hMailServer), INBOX subfolders have
+         * to be added before special folders
+         */
+        if (!$default_sub_of_inbox) {
+            for($k = 0; $k < $cnt; ++$k) {
+                if (!$used[$k] && isBoxBelow(strtolower($boxesall[$k]['unformatted']), 'inbox') &&
+                    strtolower($boxesall[$k]['unformatted']) != 'inbox') {
+                    $boxesnew[] = $boxesall[$k];
+                    $used[$k] = true;
+                }
+            }
+        }
+
+
         /* List special folders and their subfolders, if requested. */
         if ($list_special_folders_first) {
             for($k = 0; $k < $cnt; ++$k) {
@@ -696,12 +743,14 @@ function sqimap_mailbox_list($imap_stream, $force=false) {
         }
 
 
-        /* Find INBOX's children */
-        for($k = 0; $k < $cnt; ++$k) {
-            if (!$used[$k] && isBoxBelow(strtolower($boxesall[$k]['unformatted']), 'inbox') &&
-                strtolower($boxesall[$k]['unformatted']) != 'inbox') {
-                $boxesnew[] = $boxesall[$k];
-                $used[$k] = true;
+        /* Find INBOX's children for systems where folders are ONLY under INBOX */
+        if ($default_sub_of_inbox) {
+            for($k = 0; $k < $cnt; ++$k) {
+                if (!$used[$k] && isBoxBelow(strtolower($boxesall[$k]['unformatted']), 'inbox') &&
+                    strtolower($boxesall[$k]['unformatted']) != 'inbox') {
+                    $boxesnew[] = $boxesall[$k];
+                    $used[$k] = true;
+                }
             }
         }
 
