@@ -6,9 +6,9 @@
  * This contains functions that display mailbox information, such as the
  * table row that has sender, date, subject, etc...
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: mailbox_display.php 13932 2010-03-30 05:54:31Z pdontthink $
+ * @version $Id: mailbox_display.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  */
 
@@ -110,13 +110,16 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
             if ($senderNames_part[1]) {
                 $senderName .= decodeHeader($senderNames_part[1]);
             } else {
-                $senderName .= htmlspecialchars($senderNames_part[0]);
+                $senderName .= sm_encode_html_special_chars($senderNames_part[0]);
             }
 
-            $senderFrom .= htmlspecialchars($senderNames_part[0]);
+            $senderFrom .= sm_encode_html_special_chars($senderNames_part[0]);
         }
     }
     $senderName = str_replace('&nbsp;',' ',$senderName);
+    if (substr($senderName, 0, 6) == '&quot;'
+     && substr($senderName, -6) == '&quot;')
+        $senderName = substr(substr($senderName, 0, -6), 6);
     echo html_tag( 'tr','','','','valign="top"') . "\n";
 
     if (isset($msg['FLAG_FLAGGED']) && ($msg['FLAG_FLAGGED'] == true)) {
@@ -157,6 +160,7 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
     if (is_array($message_highlight_list) && count($message_highlight_list)) {
         $msg['TO'] = parseAddress($msg['TO']);
         $msg['CC'] = parseAddress($msg['CC']);
+        $decoded_addresses = array();
         foreach ($message_highlight_list as $message_highlight_list_part) {
             if (trim($message_highlight_list_part['value']) != '') {
                 $high_val   = strtolower($message_highlight_list_part['value']);
@@ -171,9 +175,12 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                         case('TO'):
                         case('CC'):
                         case('FROM'):
-                            foreach ($msg[$match_type] as $address) {
-                                $address[0] = decodeHeader($address[0], true, false);
-                                $address[1] = decodeHeader($address[1], true, false);
+                            foreach ($msg[$match_type] as $i => $address) {
+                                if (empty($decoded_addresses[$match_type][$i])) {
+                                    $decoded_addresses[$match_type][$i][0] = decodeHeader($address[0], true, false);
+                                    $decoded_addresses[$match_type][$i][1] = decodeHeader($address[1], true, false);
+                                }
+                                $address = $decoded_addresses[$match_type][$i];
                                 if (strstr('^^' . strtolower($address[0]), $high_val) ||
                                     strstr('^^' . strtolower($address[1]), $high_val)) {
                                     $hlt_color = $message_highlight_list_part['color'];
@@ -230,8 +237,10 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                 // show internal date if using it to sort
                 if ($internal_date_sort && ($sort == 0 || $sort == 1)) {
                     $date_string = $msg['RECEIVED_DATE_STRING'] . '';
+                    $date_title_string = $msg['RECEIVED_DATE_STRING_FULL'] . '';
                 } else {
                     $date_string = $msg['DATE_STRING'] . '';
+                    $date_title_string = $msg['DATE_STRING_FULL'] . '';
                 }
                 if ($date_string == '') {
                     $date_string = _("Unknown date");
@@ -241,7 +250,7 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                                $fontstr_end . $flag_end . $bold_end,
                                'center',
                                $hlt_color,
-                               'nowrap' );
+                               'nowrap title="' . $date_title_string . '"' );
                 break;
             case 4: /* subject */
                 $td_str = $bold;
@@ -523,8 +532,8 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
     $form_name = "FormMsgs" . $safe_name;
     echo '<form name="' . $form_name . '" method="post" action="move_messages.php">' ."\n" .
         '<input type="hidden" name="smtoken" value="'.sm_generate_security_token().'">' . "\n" .
-        '<input type="hidden" name="mailbox" value="'.htmlspecialchars($mailbox).'">' . "\n" .
-        '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">' . "\n";
+        '<input type="hidden" name="mailbox" value="'.sm_encode_html_special_chars($mailbox).'">' . "\n" .
+        '<input type="hidden" name="startMessage" value="'.sm_encode_html_special_chars($start_msg).'">' . "\n";
     
     echo '<table border="0" width="100%" cellpadding="0" cellspacing="0">';
     echo '<tr><td>';
@@ -848,7 +857,13 @@ function mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $colo
 }
 
 function printHeader($mailbox, $sort, $color, $showsort=true) {
-    global $index_order, $internal_date_sort;
+
+    global $index_order, $internal_date_sort, $imap_server_type;
+
+    // gmail doesn't support custom sorting, so we always
+    // hide the sort buttons when using gmail
+    if ($imap_server_type == 'gmail') $showsort = false;
+
     echo html_tag( 'tr' ,'' , 'center', $color[5] );
 
     /* calculate the width of the subject column based on the
