@@ -5,9 +5,9 @@
  *
  * Prints the page header (duh)
  *
- * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: page_header.php 12538 2007-07-14 19:04:00Z kink $
+ * @version $Id: page_header.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  */
 
@@ -18,17 +18,71 @@ require_once(SM_PATH . 'functions/imap_mailbox.php');
 require_once(SM_PATH . 'functions/global.php');
 
 /* Always set up the language before calling these functions */
-function displayHtmlHeader( $title = 'SquirrelMail', $xtra = '', $do_hook = TRUE ) {
-    global $squirrelmail_language;
+/**
+ * @param array $script_libs_param A list of strings, which each point to
+ *                                 a script to be added to the <head> of
+ *                                 the page being built. Each string can
+ *                                 be:
+ *                                  - One of the pre-defined SM_SCRIPT_LIB_XXX
+ *                                    constants (see functions/constants.php)
+ *                                    that correspond to libraries that come
+ *                                    with SquirrelMail
+ *                                  - A path to a custom script (say, in a
+ *                                    plugin directory) (detected by the
+ *                                    existence of at least one path separator
+ *                                    in the string) - the script is assumed
+ *                                    to be and is included as JavaScript
+ *                                  - A full tag ("<script>", "<style>" or
+ *                                    other) that will be placed verbatim in
+ *                                    the page header (detected by the presence
+ *                                    of a "<" character at the beginning of
+ *                                    the string). NOTE that $xtra provides the
+ *                                    same function, without needing the string
+ *                                    to start with "<"
+ */
+function displayHtmlHeader($title='SquirrelMail', $xtra_param='', $do_hook=TRUE, $script_libs_param=array()) {
+    global $squirrelmail_language, $xtra, $script_libs;
+
+    // $script_libs and $xtra are globalized to allow plugins to
+    // modify them on the generic_header hook, but we also want to
+    // respect the values passed in from the function args, thus:
+    $xtra = $xtra_param;
+    $script_libs = $script_libs_param;
+    if (!is_array($script_libs))
+        $script_libs = array($script_libs);
 
     if ( !sqgetGlobalVar('base_uri', $base_uri, SQ_SESSION) ) {
         global $base_uri;
     }
-    global $theme_css, $custom_css, $pageheader_sent;
+    global $theme_css, $custom_css, $pageheader_sent, $browser_rendering_mode;
 
-    echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">' .
+    // prevent clickjack attempts
+// FIXME: should we use DENY instead?  We can also make this a configurable value, including giving the admin the option of removing this entirely in case they WANT to be framed by an external domain
+    header('X-Frame-Options: SAMEORIGIN');
+
+    echo ($browser_rendering_mode === 'standards'
+       ? '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">'
+       : ($browser_rendering_mode === 'almost'
+         ? '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">'
+         : /* "quirks" */ '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">')) .
          "\n\n" . html_tag( 'html' ,'' , '', '', '' ) . "\n<head>\n" .
-         "<meta name=\"robots\" content=\"noindex,nofollow\">\n";
+         "<meta name=\"robots\" content=\"noindex,nofollow\">\n" .
+         "<meta http-equiv=\"x-dns-prefetch-control\" content=\"off\">\n";
+
+    // prevent clickjack attempts using JavaScript for browsers that
+    // don't support the X-Frame-Options header...
+    // we check to see if we are *not* the top page, and if not, check
+    // whether or not the top page is in the same domain as we are...
+    // if not, log out immediately -- this is an attempt to do the same
+    // thing that the X-Frame-Options does using JavaScript (never a good
+    // idea to rely on JavaScript-based solutions, though)
+    echo '<script type="text/javascript" language="JavaScript">'
+       . "\n<!--\n"
+       . 'if (self != top) { try { if (document.domain != top.document.domain) {'
+       . ' throw "Clickjacking security violation! Please log out immediately!"; /* this code should never execute - exception should already have been thrown since it\'s a security violation in this case to even try to access top.document.domain (but it\'s left here just to be extra safe) */ } } catch (e) { self.location = "'
+       . sqm_baseuri() . 'src/signout.php"; top.location = "'
+       . sqm_baseuri() . 'src/signout.php" } }'
+       . "\n// -->\n</script>\n";
 
     if ( !isset( $custom_css ) || $custom_css == 'none' ) {
         if ($theme_css != '') {
@@ -51,16 +105,30 @@ function displayHtmlHeader( $title = 'SquirrelMail', $xtra = '', $do_hook = TRUE
 
     echo "\n<title>$title</title>$xtra\n";
 
+    // output <script> tags as needed (use array_unique so
+    // more than one plugin can ask for the same library)
+    // 
+    // usage of $script_libs is discussed in the docs for this function above
+    // 
+    foreach (array_unique($script_libs) as $item) {
+        if ($item{0} === '<')
+            echo $item . "\n";
+        else if (strpos($item, '/') !== FALSE || strpos($item, '\\') !== FALSE)
+            echo '<script language="JavaScript" type="text/javascript" src="' . $item . '"></script>' . "\n";
+        else
+            echo '<script language="JavaScript" type="text/javascript" src="' . $base_uri . 'scripts/' . $item . '"></script>' . "\n";
+    }
+
     /* work around IE6's scrollbar bug */
     echo <<<ECHO
-<style type="text/css">
 <!--[if IE 6]>
+<style type="text/css">
 /* avoid stupid IE6 bug with frames and scrollbars */
 body {
     width: expression(document.documentElement.clientWidth - 30);
 }
-<![endif]-->
 </style>
+<![endif]-->
 
 ECHO;
 
@@ -248,7 +316,7 @@ function displayPageHeader($color, $mailbox, $xtra='', $session=false) {
 
     echo "<body text=\"$color[8]\" bgcolor=\"$color[4]\" link=\"$color[7]\" vlink=\"$color[7]\" alink=\"$color[7]\" $onload>\n\n";
     /** Here is the header and wrapping table **/
-    $shortBoxName = htmlspecialchars(imap_utf7_decode_local(
+    $shortBoxName = sm_encode_html_special_chars(imap_utf7_decode_local(
                       readShortMailboxName($mailbox, $delimiter)));
     if ( $shortBoxName == 'INBOX' ) {
         $shortBoxName = _("INBOX");
@@ -293,7 +361,7 @@ function displayPageHeader($color, $mailbox, $xtra='', $session=false) {
     if (!$hide_sm_attributions)
     {
         echo html_tag( 'td', '', 'right' ) ."\n";
-        if (!isset($provider_uri)) $provider_uri= 'http://www.squirrelmail.org/';
+        if (!isset($provider_uri)) $provider_uri= 'http://squirrelmail.org/';
         if (!isset($provider_name)) $provider_name= 'SquirrelMail';
         echo '<a href="'.$provider_uri.'" target="_blank">'.$provider_name.'</a>';
         echo "</td>\n";
