@@ -7,9 +7,9 @@
  *
  * Documentation on how to write plugins might show up some time.
  *
- * @copyright 1999-2011 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: plugin.php 14084 2011-01-06 02:44:03Z pdontthink $
+ * @version $Id: plugin.php 14444 2014-03-14 04:10:27Z pdontthink $
  * @package squirrelmail
  */
 
@@ -68,7 +68,7 @@ function do_hook ($name) {
  */
 function do_hook_function($name,$parm=NULL) {
     global $squirrelmail_plugin_hooks;
-    $ret = '';
+    $ret = NULL;
 
     if (isset($squirrelmail_plugin_hooks[$name])
           && is_array($squirrelmail_plugin_hooks[$name])) {
@@ -170,6 +170,7 @@ function boolean_hook_function($name,$parm=NULL,$priority=0,$tie=false) {
  * offending browser.
  * *** THIS IS A TEST FOR JAVASCRIPT SUPPORT ***
  * FIXME: This function needs to have its name changed!
+ * FIXME: The test in this function is outdated - plenty more browsers support JavaScript, newer browser versions (Mozilla at least) exist, and moreover, we shouldn't be doing user-agent testing - should be trusting our $javascript_on global -- REMOVE THIS FUNCTION IF NOT BEING USED ANYWHERE ELSE
  *
  * @return bool whether this browser properly supports JavaScript
  */
