@@ -6,9 +6,9 @@
  * Loads preferences from the $username.pref file used by almost
  * every other script in the source directory and alswhere.
  *
- * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: load_prefs.php 13549 2009-04-15 22:00:49Z jervfors $
+ * @version $Id: load_prefs.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  */
 
@@ -236,6 +236,9 @@ $pf_cleandisplay = getPref($data_dir, $username, 'pf_cleandisplay', SMPREF_OFF);
 /* message disposition notification support setting */
 $mdn_user_support = getPref($data_dir, $username, 'mdn_user_support', SMPREF_ON);
 
+$do_not_reply_to_self =
+    getPref($data_dir, $username, 'do_not_reply_to_self', SMPREF_OFF);
+
 $include_self_reply_all =
     getPref($data_dir, $username, 'include_self_reply_all', SMPREF_ON);
 
@@ -256,6 +259,9 @@ $compose_width = getPref($data_dir, $username, 'compose_width', 640);
 /* signature placement settings */
 $sig_first = getPref($data_dir, $username, 'sig_first', 0);
 
+/* strip signature from replies setting */
+$strip_sigs = getPref($data_dir, $username, 'strip_sigs', 0);
+
 /* use the internal date of the message for sorting instead of the supplied header date */
 $internal_date_sort = getPref($data_dir, $username, 'internal_date_sort', SMPREF_ON);
 
