@@ -5,9 +5,9 @@
  *
  * Displays all optinos about display preferences
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: display.php 13916 2010-02-16 20:20:57Z pdontthink $
+ * @version $Id: display.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  */
 
@@ -74,6 +74,7 @@ function load_optpage_data_display() {
         closedir($handle);
     }
 
+    asort($css_values);
     if ( count( $css_values ) > 1 ) {
 
         $optvals[SMOPT_GRP_GENERAL][] = array(
@@ -263,6 +264,13 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_NONE
     );
 
+    $optvals[SMOPT_GRP_MESSAGE][] = array(
+        'name'    => 'do_not_reply_to_self',
+        'caption' => _("Send Replies To My Own Messages To Previous Recipient"),
+        'type'    => SMOPT_TYPE_BOOLEAN,
+        'refresh' => SMOPT_REFRESH_NONE
+    );
+
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'include_self_reply_all',
         'caption' => _("Include Me in CC when I Reply All"),
