@@ -5,9 +5,9 @@
  *
  * Displays all options relating to folders
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folder.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: folder.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package squirrelmail
  */
 
@@ -34,12 +34,12 @@ define('SMOPT_GRP_FOLDERSELECT', 2);
  * @return array all option information
  */
 function load_optpage_data_folder() {
-    global $username, $key, $imapServerAddress, $imapPort;
+    global $username, $key, $imapServerAddress, $imapPort, $imap_stream_options;
     global $folder_prefix, $default_folder_prefix, $show_prefix_option;
 
     /* Get some imap data we need later. */
     $imapConnection =
-        sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+        sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
     $boxes = sqimap_mailbox_list($imapConnection);
 
     /* Build a simple array into which we will build options. */
