@@ -3,9 +3,9 @@
 /**
  * validate.php
  *
- * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: validate.php 13549 2009-04-15 22:00:49Z jervfors $
+ * @version $Id: validate.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  */
 
@@ -77,3 +77,17 @@ if ( $timeZone != SMPREF_NONE && ($timeZone != "")
     putenv("TZ=".$timeZone);
 }
 
+/**
+ * php 5.1.0 added time zone functions. Set time zone with them in order
+ * to prevent E_STRICT notices and allow time zone modifications in safe_mode.
+ */
+if (function_exists('date_default_timezone_set')) {
+    if ($timeZone != SMPREF_NONE && $timeZone != "") {
+        date_default_timezone_set($timeZone);
+    } else {
+        // interface runs on server's time zone. Remove php E_STRICT complains
+        $default_timezone = @date_default_timezone_get();
+        date_default_timezone_set($default_timezone);
+    }
+}
+
