@@ -4,9 +4,9 @@
  * Administrator plugin - Option definitions
  *
  * @author Philippe Mingo
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: defines.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: defines.php 14430 2014-01-21 03:19:33Z pdontthink $
  * @package plugins
  * @subpackage administrator
  */
@@ -265,6 +265,12 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                                    'type' => SMOPT_TYPE_STRING,
                                                    'size' => 40,
                                                    'default' => '' ),
+                 '$use_transparent_security_image' => array( 'name' => _("Use transparent security image"),
+                                          'type' => SMOPT_TYPE_BOOLEAN,
+                                          'default' => true ),
+                 '$display_imap_login_error' => array( 'name' => _("Show login error message directly from IMAP server instead of generic one"),
+                                          'type' => SMOPT_TYPE_BOOLEAN,
+                                          'default' => false ),
                  /* --------------------------------------------------------*/
                  'Group5' => array( 'name' => _("Message of the Day"),
                                     'type' => SMOPT_TYPE_TITLE ),
