@@ -8,12 +8,12 @@
  * a button to show the bug report mail message in order to actually
  * send it.
  *
- * Copyright (c) 1999-2010 The SquirrelMail Project Team
+ * Copyright (c) 1999-2014 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This is a standard Squirrelmail-1.2 API for plugins.
  *
- * @version $Id: bug_report.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: bug_report.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package plugins
  * @subpackage bug_report
  */
@@ -163,7 +163,7 @@ if (isset($warning) && $warning) {
     $body_top .= "----------------------------------------------\n";
 }
 
-$body = htmlspecialchars($body_top . $body);
+$body = sm_encode_html_special_chars($body_top . $body);
 
 ?>
     <br />
