@@ -18,8 +18,8 @@
  *
  * Also view plugins/README.plugins for more information.
  *
- * @version $Id: filters.php 13893 2010-01-25 02:47:41Z pdontthink $
- * @copyright (c) 1999-2010 The SquirrelMail Project Team
+ * @version $Id: filters.php 14436 2014-01-21 21:30:59Z pdontthink $
+ * @copyright (c) 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
  * @package plugins
  * @subpackage filters
@@ -180,7 +180,7 @@ function filters_bulkquery($filters_spam_scan, $filters, $read) {
  * @access private
  */
 function start_filters() {
-    global $mailbox, $imapServerAddress, $imapPort, $imap,
+    global $mailbox, $imapServerAddress, $imapPort, $imap_stream_options,
            $imap_general, $filters, $imap_stream, $imapConnection,
            $UseSeparateImapConnection, $AllowSpamFilters;
 
@@ -214,7 +214,7 @@ function start_filters() {
     if ((!isset($imap_stream) && !isset($imapConnection)) ||
         $UseSeparateImapConnection ) {
             $stream = sqimap_login($username, $key, $imapServerAddress,
-                                $imapPort, 10);
+                                $imapPort, 10, $imap_stream_options);
             $previously_connected = false;
     } else if (isset($imapConnection)) {
         $stream = $imapConnection;
@@ -335,7 +335,7 @@ function filter_search_and_delete($imap, $where, $what, $where_to, $user_scan,
         $read = sqimap_run_command_list($imap, $search_str, true, $response, $message, $uid_support);        
     } else {
     	$lit = array();
-    	$lit['command'] = $search_str . ' ' . $where;
+    	$lit['commands'][] = $search_str . ' ' . $where;
     	$lit['literal_args'][] = $what;
     	
 		$read = sqimap_run_literal_command($imap, $lit, true, $response, $message, $uid_support );
