@@ -1,7 +1,7 @@
 <?php
 
 /* functions for info plugin
- * Copyright (c) 1999-2010 The SquirrelMail Project Team
+ * Copyright (c) 1999-2014 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * Here are two functions for the info plugin
@@ -11,7 +11,7 @@
  * to options.php.
  * by: Jason Munro jason@stdbev.com
  *
- * $Id: functions.php 13893 2010-01-25 02:47:41Z pdontthink $ 
+ * $Id: functions.php 14422 2014-01-01 20:59:43Z pdontthink $ 
  *
  */
 
@@ -30,7 +30,7 @@ function imap_test($imap_stream, $string) {
     $sid = sqimap_session_id();
     $results = array();
     $query = "$sid ".trim($string)."\r\n";
-    print "<tr><td>".htmlspecialchars($query)."</td></tr>";
+    print "<tr><td>".sm_encode_html_special_chars($query)."</td></tr>";
     fputs ($imap_stream, $query);
     $response = sqimap_read_data_list($imap_stream, $sid, false, $responses, $message);
     array_push($response, $message);
@@ -43,7 +43,7 @@ function print_response($response) {
             print_response($value);
         }
         else {
-            print htmlspecialchars($value)."<br>\n";
+            print sm_encode_html_special_chars($value)."<br>\n";
         }
     }
 }
