@@ -1,7 +1,7 @@
 <?php
 
 /* options page for IMAP info plugin 
- * Copyright (c) 1999-2010 The SquirrelMail Project Team
+ * Copyright (c) 1999-2014 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *   
  * This is where it all happens :)
@@ -9,7 +9,7 @@
  * Written by: Jason Munro 
  * jason@stdbev.com
  * 
- * $Id: options.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * $Id: options.php 14436 2014-01-21 21:30:59Z pdontthink $
  * 
  */
 
@@ -55,7 +55,8 @@ for($i = 0; $i <= 9; $i++){
 
 /* END GLOBALS */
 
-$imap_stream = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+global $imap_stream_options; // in case not defined in config
+$imap_stream = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
 $caps_array = get_caps($imap_stream);
 $list = array (
                'TEST_0',
@@ -75,7 +76,7 @@ print "<center><table width=\"95%\" border=\"1\" bgcolor=\"".$color[3]."\">\n";
 print "<tr><td bgcolor=\"".$color[4]."\"><b>Server Capability response:</b><br>\n";
 
 foreach($caps_array[0] as $value) {
-    print htmlspecialchars($value);
+    print sm_encode_html_special_chars($value);
 }
 
 print "</td></tr><tr><td>\n";
@@ -94,8 +95,8 @@ if (!isset($submit) || $submit == 'default') {
     }
 }
 else {
-    print 'folder_prefix = ' . htmlspecialchars($folder_prefix) . "<br>\n".
-          'default_charset = ' . htmlspecialchars($default_charset) . "\n";
+    print 'folder_prefix = ' . sm_encode_html_special_chars($folder_prefix) . "<br>\n".
+          'default_charset = ' . sm_encode_html_special_chars($default_charset) . "\n";
 }
 
 print "<br></td></tr></table></center><br>\n";
