@@ -1,20 +1,22 @@
-<?php 
+<?php
 
-   /**
-    * mail_fetch/setup.php
-    *
-    * Copyright (c) 1999-2006 The SquirrelMail Project Team
-    *
-    * Copyright (c) 1999 CDI (cdi@thewebmasters.net) All Rights Reserved
-    * Modified by Philippe Mingo 2001 mingo@rotedic.com
-    * An RFC 1939 compliant wrapper class for the POP3 protocol.
-    *
-    * Licensed under the GNU GPL. For full terms see the file COPYING.
-    *
-    * pop3 class
-    *
-    * $Id: class.POP3.php 12426 2007-05-30 18:52:34Z kink $
-    */
+/**
+ * mail_fetch/setup.php
+ *
+ * Copyright (c) 1999-2012 CDI (cdi@thewebmasters.net) All Rights Reserved
+ * Modified by Philippe Mingo 2001-2009 mingo@rotedic.com
+ * An RFC 1939 compliant wrapper class for the POP3 protocol.
+ *
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
+ * POP3 class
+ *
+ * @copyright 1999-2014 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: class.POP3.php 14422 2014-01-01 20:59:43Z pdontthink $
+ * @package plugins
+ * @subpackage mail_fetch
+ */
 
 class POP3 {
     var $ERROR      = '';       //  Error string.
@@ -251,7 +253,7 @@ class POP3 {
         $MsgArray = array();
 
         $line = fgets($fp,$buffer);
-        while ( !ereg("^\.\r\n",$line))
+        while ( !preg_match('/^\.\r\n/',$line))
         {
             $MsgArray[$count] = $line;
             $count++;
@@ -318,7 +320,7 @@ class POP3 {
             if($msgC > $Total) { break; }
             $line = fgets($fp,$this->BUFFER);
             $line = $this->strip_clf($line);
-            if(ereg("^\.",$line))
+            if(strpos($line, '.') === 0)
             {
                 $this->ERROR = "POP3 pop_list: " . _("Premature end of list");
                 return false;
@@ -364,7 +366,7 @@ class POP3 {
         $MsgArray = array();
 
         $line = fgets($fp,$buffer);
-        while ( !ereg("^\.\r\n",$line))
+        while ( !preg_match('/^\.\r\n/',$line))
         {
             if ( $line{0} == '.' ) { $line = substr($line,1); }
             $MsgArray[$count] = $line;
@@ -552,10 +554,7 @@ class POP3 {
             $line = "";
             $count = 1;
             $line = fgets($fp,$buffer);
-            while ( !ereg("^\.\r\n",$line)) {
-                if(ereg("^\.\r\n",$line)) {
-                    break;
-                }
+            while ( !preg_match('/^\.\r\n/',$line)) {
                 list ($msg,$msgUidl) = preg_split('/\s+/',$line);
                 $msgUidl = $this->strip_clf($msgUidl);
                 if($count == $msg) {
@@ -605,7 +604,7 @@ class POP3 {
         if( empty($cmd) )
             return false;
         else
-            return( ereg ("^\+OK", $cmd ) );
+            return( stripos($cmd, '+OK') !== false );
     }
 
     function strip_clf ($text = "") {
@@ -614,8 +613,7 @@ class POP3 {
         if(empty($text))
             return $text;
         else {
-            $stripped = str_replace("\r",'',$text);
-            $stripped = str_replace("\n",'',$stripped);
+            $stripped = str_replace(array("\r","\n"),'',$text);
             return $stripped;
         }
     }
@@ -648,3 +646,11 @@ class POP3 {
 
 }   // End class
 
+// For php4 compatibility
+if (!function_exists("stripos")) {
+    function stripos($haystack, $needle){
+        return strpos($haystack, stristr( $haystack, $needle ));
+    }
+}
+
+
