@@ -5,9 +5,9 @@
  *
  * Setup of the mailfetch plugin.
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: setup.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: setup.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package plugins
  * @subpackage mail_fetch
  */
@@ -69,7 +69,7 @@ function mail_fetch_login() {
     require_once (SM_PATH . 'plugins/mail_fetch/class.POP3.php');
     require_once (SM_PATH . 'plugins/mail_fetch/functions.php');
 
-    global $data_dir, $imapServerAddress, $imapPort;
+    global $data_dir, $imapServerAddress, $imapPort, $imap_stream_options;
         
     sqgetGlobalVar('username', $username, SQ_SESSION);
     sqgetGlobalVar('key',      $key,      SQ_COOKIE);
@@ -123,7 +123,7 @@ function mail_fetch_login() {
                 continue;
             }
 
-            $imap_stream = sqimap_login($username, $key, $imapServerAddress, $imapPort, 10);
+            $imap_stream = sqimap_login($username, $key, $imapServerAddress, $imapPort, 10, $imap_stream_options);
 
             $Count = $pop3->login($mailfetch_user, $mailfetch_pass);
             if (($Count == false || $Count == -1) && $pop3->ERROR != '') {
