@@ -8,9 +8,9 @@
  *
  * @author Marc Groot Koerkamp
  * @copyright 2002 Marc Groot Koerkamp, The Netherlands
- * @copyright 2004-2010 The SquirrelMail Project Team
+ * @copyright 2004-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: message_details_bottom.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: message_details_bottom.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package plugins
  * @subpackage message_details
  */
@@ -33,6 +33,7 @@ sqgetGlobalVar('mailbox', $mailbox, SQ_GET);
 sqgetGlobalVar('username', $username, SQ_SESSION);
 sqgetGlobalVar('key', $key, SQ_COOKIE);
 sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
+global $imap_stream_options; // in case not defined in config
 
 /**
  * Calculates id of MIME entity
@@ -71,7 +72,7 @@ function CalcEntity($entString, $direction) {
     return ($result);
 }
 
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
 $read = sqimap_mailbox_select($imapConnection, $mailbox);
 if (!empty($passed_ent_id))
     $body = sqimap_run_command($imapConnection, "FETCH $passed_id BODY[$passed_ent_id]",true, $response, $readmessage, $uid_support);
@@ -85,7 +86,7 @@ $messageheader = true;
 $messageheaderstart=false;
 $boundaries = array();
 $entities = array();
-session_unregister("entities");
+sqsession_unregister("entities");
 $pre = '<b>';
 $end = '</b>';
 $entStr = '';
@@ -215,7 +216,7 @@ for ($i=1; $i < $count; $i++) {
 			$entities["$entStr"]['contenttype']=$reg[2].'/'.$reg[3];
 		    }	
    		} else if (!$nameset && preg_match("/^.*(name=\s*)\"(.*)\".*/i",$line,$reg)) {
-		    $name = htmlspecialchars($reg[2]);
+		    $name = sm_encode_html_special_chars($reg[2]);
 		    $content[$content_indx]['name'] = decodeHeader($name);
 		    $nameset = true;
 		    if (isset($entities["$entStr"])) {
@@ -246,7 +247,7 @@ for ($i=1; $i < $count; $i++) {
         }
     } 	
 */
-    $line = htmlspecialchars($line);
+    $line = sm_encode_html_special_chars($line);
     $message_body .= "$pre"."$line"."$end".'<br />'."\r\n";
 }
 
