@@ -3,12 +3,12 @@
 /**
  * newmails_opt.php
  *
- * Copyright (c) 1999-2010 The SquirrelMail Project Team
+ * Copyright (c) 1999-2014 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * Displays all options relating to new mail sounds
  *
- * $Id: newmail_opt.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * $Id: newmail_opt.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package plugins
  * @subpackage newmail
  */
@@ -159,8 +159,8 @@ if ($allowsound == "true") {
             if ($fname == $media) {
                 echo 'selected="selected" ';
             }
-            echo 'value="' . htmlspecialchars($fname) . '">' .
-                htmlspecialchars($entry) . "</option>\n";
+            echo 'value="' . sm_encode_html_special_chars($fname) . '">' .
+                sm_encode_html_special_chars($entry) . "</option>\n";
         }
     }
     $d->close();
@@ -174,8 +174,8 @@ if ($allowsound == "true") {
             html_tag( 'tr', "\n" .
                 html_tag( 'td', _("Current File:"), 'right', '', 'nowrap' ) .
                     html_tag( 'td', '<input type="hidden" value="' .
-                        htmlspecialchars($media) . '" name="media_default">' .
-                        htmlspecialchars($media_output) . '', 'left' )
+                        sm_encode_html_special_chars($media) . '" name="media_default">' .
+                        sm_encode_html_special_chars($media_output) . '', 'left' )
              ) . "\n";
 }
 echo html_tag( 'tr', "\n" .
