@@ -3,7 +3,7 @@
 /**
  * newmail.php
  *
- * Copyright (c) 1999-2010 The SquirrelMail Project Team
+ * Copyright (c) 1999-2014 The SquirrelMail Project Team
  * Copyright (c) 2000 by Michael Huttinger
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
@@ -22,7 +22,7 @@
  * This was tested with IE5.0 - but I hear Netscape works well,
  * too (with a plugin).
  *
- * @version $Id: setup.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: setup.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package plugins
  * @subpackage new_mail
  */
@@ -220,16 +220,17 @@ function newmail_plugin() {
         // will play the sound as follows:
 
         if ($newmail_changetitle) {
+            global $org_title;
             echo "<script language=\"javascript\" type=\"text/javascript\">\n" .
                 "function ChangeTitleLoad() {\n";
             if( $totalNew > 1 || $totalNew == 0 ) {
-                echo 'window.parent.document.title = "' .
+                echo 'window.parent.document.title = "' . $org_title . ' [' .
                     sprintf(_("%s New Messages"), $totalNew ) . 
-                    "\";\n";
+                    "]\";\n";
             } else {
-                echo 'window.parent.document.title = "' .
+                echo 'window.parent.document.title = "' . $org_title . ' [' .
                     sprintf(_("%s New Message"), $totalNew ) . 
-                    "\";\n";
+                    "]\";\n";
             }
             echo    "if (BeforeChangeTitle != null)\n".
                 "BeforeChangeTitle();\n".
@@ -241,7 +242,7 @@ function newmail_plugin() {
 
         if ($totalNew > 0 && $newmail_enable == 'on' && $newmail_media != '' && $newmail_media != '(none)') {
             $newmail_media=sqm_baseuri().'plugins/newmail/sounds/'.basename($newmail_media);
-            echo '<embed src="'.htmlspecialchars($newmail_media)
+            echo '<embed src="'.sm_encode_html_special_chars($newmail_media)
                 ."\" hidden=\"true\" autostart=\"true\" width=\"2\" height=\"2\">\n";
         }
         if ($totalNew > 0 && $newmail_popup == 'on') {
