@@ -3,10 +3,10 @@
 /**
  * testsound.php
  *
- * Copyright (c) 1999-2011 The SquirrelMail Project Team
+ * Copyright (c) 1999-2014 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.        
  *
- * $Id: testsound.php 14084 2011-01-06 02:44:03Z pdontthink $
+ * $Id: testsound.php 14422 2014-01-01 20:59:43Z pdontthink $
  */
 
 define('SM_PATH','../../');
@@ -34,7 +34,7 @@ if ( ! sqgetGlobalVar('sound', $sound, SQ_GET) ) {
 echo html_tag( 'table',
          html_tag( 'tr',
              html_tag( 'td',
-                    '<embed src="'.htmlspecialchars($sound).'" hidden="true" autostart="true" width="2" height="2">'.
+                    '<embed src="'.sm_encode_html_special_chars($sound).'" hidden="true" autostart="true" width="2" height="2">'.
                     '<br>'.
                     '<b>' . _("Loading the sound...") . '</b><br>'.
                     '<form>'.
