@@ -3,12 +3,12 @@
 /**
  * setup.php -- Sent Subfolders Setup File
  *
- * Copyright (c) 1999-2010 The SquirrelMail Project Team
+ * Copyright (c) 1999-2014 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This is a standard Squirrelmail-1.2 API for plugins.
  *
- * $Id: setup.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * $Id: setup.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package plugins
  * @subpackage sent_subfolders
  */
@@ -102,14 +102,14 @@ function sent_subfolders_load_prefs() {
  * Adds sent_subfolders options in folder preferences
  */
 function sent_subfolders_optpage_loadhook_folders() {
-    global $optpage_data, $imapServerAddress, $imapPort;
+    global $optpage_data, $imapServerAddress, $imapPort, $imap_stream_options;
 
     sqgetGlobalVar('username', $username, SQ_SESSION);
     sqgetGlobalVar('key', $key, SQ_COOKIE);
 
     /* Get some imap data we need later. */
     $imapConnection =
-        sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+        sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
     $boxes = sqimap_mailbox_list($imapConnection);
     sqimap_logout($imapConnection);
 
@@ -172,6 +172,10 @@ function save_option_sent_subfolders_setting($option) {
     } else {
         setPref($data_dir, $username, 'use_sent_subfolders', SMPREF_ON);
         setPref($data_dir, $username, 'move_to_sent', SMPREF_ON);
+        $check_sent_subfolders_base = getPref($data_dir, $username, 'sent_subfolders_base', '');
+        if ($check_sent_subfolders_base === '') {
+            setPref($data_dir, $username, 'sent_subfolders_base', $sent_subfolders_base);
+        }
     }
 
     /* Now just save the option as normal. */
@@ -187,7 +191,7 @@ function save_option_sent_subfolders_setting($option) {
 function sent_subfolders_update_sentfolder() {
     global $sent_folder, $auto_create_special, $auto_create_done;
     global $sent_subfolders_base, $sent_subfolders_setting;
-    global $data_dir, $imapServerAddress, $imapPort;
+    global $data_dir, $imapServerAddress, $imapPort, $imap_stream_options;
     global $use_sent_subfolders, $move_to_sent, $imap_server_type;
 
     sqgetGlobalVar('username', $username, SQ_SESSION);
@@ -255,7 +259,7 @@ function sent_subfolders_update_sentfolder() {
             if ($sent_folder != 'none') {
                 /* Create the imap connection. */
                 $ic = sqimap_login
-                ($username, $key, $imapServerAddress, $imapPort, 10);
+                ($username, $key, $imapServerAddress, $imapPort, 10, $imap_stream_options);
 
                 /* Auto-create the year folder, if it does not yet exist.
                    (only for monthly/quarterly modes */
