@@ -3,10 +3,10 @@
    /**
     **  options.php -- SpamCop options page
     **
-    **  Copyright (c) 1999-2010 The SquirrelMail Project Team
+    **  Copyright (c) 1999-2014 The SquirrelMail Project Team
     **  Licensed under the GNU GPL. For full terms see the file COPYING.
     **
-    **  $Id: options.php 13943 2010-06-20 17:14:41Z jangliss $
+    **  $Id: options.php 14422 2014-01-01 20:59:43Z pdontthink $
     **/
 
 define('SM_PATH','../../');
@@ -130,7 +130,7 @@ spamcop_load();
 	    '<small>(' . _("see below") . ')</small>','right','','valign="top"');
 	  ?>
 	  <td valign="top"><form method="post" action="options.php">
-	    <input type="text" size="30" name="ID" value="<?php echo htmlspecialchars($spamcop_id) ?>" />
+	    <input type="text" size="30" name="ID" value="<?php echo sm_encode_html_special_chars($spamcop_id) ?>" />
 	    <input type="hidden" name="action" value="save_id" />
 	    <?php
 		echo '<input type="submit" value="' . _("Save ID") . "\" />\n";
