@@ -4,11 +4,11 @@
  * -----------
  * Squirrelspell setup file, as defined by the SquirrelMail-1.2 API.
  *
- * Copyright (c) 1999-2010 The SquirrelMail Project Team
+ * Copyright (c) 1999-2014 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * @author Konstantin Riabitsev <icon@duke.edu>
- * @version $Id: setup.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: setup.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package plugins
  * @subpackage squirrelspell
  */
@@ -27,8 +27,6 @@ function squirrelmail_plugin_init_squirrelspell() {
       'squirrelspell_setup';
   $squirrelmail_plugin_hooks['optpage_register_block']['squirrelspell'] =
       'squirrelspell_optpage_register_block';
-  $squirrelmail_plugin_hooks['options_link_and_description']['squirrelspell'] =
-      'squirrelspell_options';
 }
 
 /**
@@ -38,18 +36,17 @@ function squirrelmail_plugin_init_squirrelspell() {
  * @return void
  */
 function squirrelspell_optpage_register_block() {
-  global $optpage_blocks;
-  /**
-   * soupNazi checks if this browser is capable of using the plugin.
-   */
-  if (!soupNazi()) {
-    /**
-     * The browser checks out.
-     * Register Squirrelspell with the $optionpages array.
-     */
+  global $optpage_blocks, $javascript_on, $squirrelmail_language;
+  if ($javascript_on) {
+    // this is a hack to avoid having to change the strings
+    // in all our translations for this misspelled word
+    if (strpos($squirrelmail_language, 'en_') === 0)
+        $name = 'Spell Checker Options';
+    else
+        $name = _("SpellChecker Options");
     $optpage_blocks[] =
       array(
-        'name' => _("SpellChecker Options"),
+        'name' => $name,
         'url'  => '../plugins/squirrelspell/sqspell_options.php',
         'desc' => _("Here you may set up how your personal dictionary is stored, edit it, or choose which languages should be available to you when spell-checking."),
         'js'   => TRUE);
@@ -63,27 +60,11 @@ function squirrelspell_optpage_register_block() {
  * @return void
  */
 function squirrelspell_setup() {
-  /**
-   * Check if this browser is capable of displaying SquirrelSpell
-   * correctly.
-   */
-  if (!soupNazi()) {
-    /**
-     * Some people may choose to disable javascript even though their
-     * browser is capable of using it. So these freaks don't complain,
-     * use document.write() so the "Check Spelling" button is not
-     * displayed if js is off in the browser.
-     */
-    echo "<script type=\"text/javascript\">\n".
-      "<!--\n".
-      'document.write("<input type=\"button\" value=\"'.
-      _("Check Spelling").
-      '\" name=\"check_spelling\" onclick=\"window.open(\'../plugins/squirrelspell/sqspell_'.
-      'interface.php\', \'sqspell\', \'status=yes,width=550,height=370,'.
-      'resizable=yes\')\" />");' . "\n".
-      "//-->\n".
-      "</script>\n";
-  }
+    global $javascript_on;
+    if ($javascript_on) {
+        echo '<input type="button" value="'
+           . _("Check Spelling")
+           . '" name="check_spelling" onclick="window.open(\'../plugins/squirrelspell/sqspell_interface.php\', \'sqspell\', \'status=yes,width=550,height=370,resizable=yes\')" />';
+    }
 }
 
-?>
\ No newline at end of file
