@@ -4,11 +4,11 @@
  * ----------------------
  * All SquirrelSpell-wide functions are in this file.
  *
- * Copyright (c) 1999-2010 The SquirrelMail Project Team
+ * Copyright (c) 1999-2014 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * @author Konstantin Riabitsev <icon@duke.edu>
- * @version $Id: sqspell_functions.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: sqspell_functions.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package plugins
  * @subpackage squirrelspell
  */
@@ -55,12 +55,19 @@ function sqspell_makePage($title, $scriptsrc, $body){
    * starting page.
    */
   if ($MOD != "options_main"){
+    // this is a hack to avoid having to change the strings
+    // in all our translations for this misspelled word
+    global $squirrelmail_language;
+    if (strpos($squirrelmail_language, 'en_') === 0)
+        $text = 'Back to &quot;Spell Checker Options&quot; page';
+    else
+        $text = _("Back to &quot;SpellChecker Options&quot; page");
     echo html_tag( 'tr', "\n" .
                 html_tag( 'td', '<hr />', 'left' )
             ) . "\n"
       . html_tag( 'tr', "\n" .
             html_tag( 'td', '<a href="sqspell_options.php">'
-                . _("Back to &quot;SpellChecker Options&quot; page")
+                . $text
                 . '</a>',
             'center' )
         ) . "\n";
