@@ -3,10 +3,10 @@
 /**
  * setup.php
  *
- * Copyright (c) 1999-2010 The SquirrelMail Project Team
+ * Copyright (c) 1999-2014 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * @version $Id: setup.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: setup.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package plugins
  * @subpackage translate
  */
@@ -226,7 +226,7 @@ function translate_new_form($action,$charset=null) {
     }
 
     if (! is_null($charset))
-        echo ' accept-charset="'.htmlspecialchars($charset).'"';
+        echo ' accept-charset="'.sm_encode_html_special_chars($charset).'"';
 
     echo ">\n";
 
@@ -251,7 +251,7 @@ function translate_form_babelfish($message) {
     <input type="hidden" name="doit" value="done" />
     <input type="hidden" name="intl" value="1" />
     <input type="hidden" name="tt" value="urltext" />
-    <input type="hidden" name="urltext" value="<?php echo htmlspecialchars($message); ?>" />
+    <input type="hidden" name="urltext" value="<?php echo sm_encode_html_special_chars($message); ?>" />
     <select name="lp"><?php
         echo translate_lang_opt('zh_CN',  '',     'zh_en',
                             sprintf( _("%s to %s"),_("Chinese, Simplified"),_("English"))) .
