@@ -7,9 +7,9 @@
  *
  * This file is included from compose.php
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: addrbook_search_html.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: addrbook_search_html.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  * @subpackage addressbook
  */
@@ -47,7 +47,7 @@ sqgetGlobalVar('backend',   $backend,   SQ_POST);
  * Insert hidden data
  */
 function addr_insert_hidden() {
-    global $body, $subject, $send_to, $send_to_cc, $send_to_bcc, $mailbox,
+    global $body, $subject, $send_to, $send_to_cc, $send_to_bcc, $mailbox, $action,
            $mailprio, $request_mdn, $request_dr, $identity, $session, $composeMessage;
 
    if (substr($body, 0, 1) == "\r") {
@@ -60,6 +60,7 @@ function addr_insert_hidden() {
        echo addHidden('attachments', serialize($composeMessage->entities));
 
    echo addHidden('session', $session).
+        addHidden('smaction', $action).
         addHidden('subject', $subject).
         addHidden('send_to', $send_to).
         addHidden('send_to_bcc', $send_to_bcc).
@@ -102,18 +103,18 @@ function addr_display_result($res, $includesource = true) {
             "}\n" .
             "//-->\n" .
             "</script>\n";
-        $chk_all = '<a href="#" onClick="CheckAll(\'T\');">' . _("All") . '</a>&nbsp;<font color="'.$color[9].'">'._("To").'</font>'.
+        $chk_all = '<a href="#" onClick="CheckAll(\'T\');">' . _("All") . '</a>&nbsp;<font color="'.$color[6].'">'._("To").'</font>'.
             '&nbsp;&nbsp;'.
-            '<a href="#" onClick="CheckAll(\'C\');">' . _("All") . '</a>&nbsp;<font color="'.$color[9].'">'._("Cc").'</font>'.
+            '<a href="#" onClick="CheckAll(\'C\');">' . _("All") . '</a>&nbsp;<font color="'.$color[6].'">'._("Cc").'</font>'.
             '&nbsp;&nbsp;'.
-            '<a href="#" onClick="CheckAll(\'B\');">' . _("All") . '</a>';
+            '<a href="#" onClick="CheckAll(\'B\');">' . _("All") . '</a>&nbsp;<font color="'.$color[6].'">'._("Bcc").'</font>';
     } else {
         // check_all links are implemented only in JavaScript. disable links in js=off environment.
         $chk_all = '';
     }
     echo html_tag( 'table', '', 'center', '', 'border="0" width="98%"' ) .
     html_tag( 'tr', '', '', $color[9] ) .
-    html_tag( 'th', '&nbsp;' . $chk_all, 'left' ) .
+    html_tag( 'th', '&nbsp;' . $chk_all, 'left', '', ' style="white-space: nowrap;" ' ) .
     html_tag( 'th', '&nbsp;' . _("Name"), 'left' ) .
     html_tag( 'th', '&nbsp;' . _("E-mail"), 'left' ) .
     html_tag( 'th', '&nbsp;' . _("Info"), 'left' );
@@ -136,15 +137,15 @@ function addr_display_result($res, $includesource = true) {
         echo html_tag( 'tr', '', '', $tr_bgcolor, 'nowrap' ) .
         html_tag( 'td',
              '<input type="checkbox" name="send_to_search[T' . $line . ']" value = "' .
-             htmlspecialchars($email) . '" />&nbsp;' . _("To") . '&nbsp;' .
+             sm_encode_html_special_chars($email) . '" />&nbsp;' . _("To") . '&nbsp;' .
              '<input type="checkbox" name="send_to_search[C' . $line . ']" value = "' .
-             htmlspecialchars($email) . '" />&nbsp;' . _("Cc") . '&nbsp;' .
+             sm_encode_html_special_chars($email) . '" />&nbsp;' . _("Cc") . '&nbsp;' .
              '<input type="checkbox" name="send_to_search[B' . $line . ']" value = "' .
-             htmlspecialchars($email) . '" />&nbsp;' . _("Bcc") . '&nbsp;' ,
+             sm_encode_html_special_chars($email) . '" />&nbsp;' . _("Bcc") . '&nbsp;' ,
         'center', '', 'width="5%" nowrap' ) .
-        html_tag( 'td', '&nbsp;' . htmlspecialchars($row['lastname']) . ' ' . htmlspecialchars($row['firstname']) . '&nbsp;', 'left', '', 'nowrap' ) .
-        html_tag( 'td', '&nbsp;' . htmlspecialchars($row['email']) . '&nbsp;', 'left', '', 'nowrap' ) .
-        html_tag( 'td', '&nbsp;' . htmlspecialchars($row['label']) . '&nbsp;', 'left', '', 'nowrap' );
+        html_tag( 'td', '&nbsp;' . sm_encode_html_special_chars($row['lastname']) . ' ' . sm_encode_html_special_chars($row['firstname']) . '&nbsp;', 'left', '', 'nowrap' ) .
+        html_tag( 'td', '&nbsp;' . sm_encode_html_special_chars($row['email']) . '&nbsp;', 'left', '', 'nowrap' ) .
+        html_tag( 'td', '&nbsp;' . sm_encode_html_special_chars($row['label']) . '&nbsp;', 'left', '', 'nowrap' );
             } else {
         echo html_tag( 'tr', '', '', $tr_bgcolor, 'nowrap' ) .
         html_tag( 'td',
@@ -155,9 +156,9 @@ function addr_display_result($res, $includesource = true) {
             addCheckBox('send_to_search[B'.$line.']', FALSE, $email).
             '&nbsp;' . _("Bcc") . '&nbsp;' ,
         'center', '', 'width="5%" nowrap' ) .
-        html_tag( 'td', '&nbsp;' . htmlspecialchars($row['name']) . '&nbsp;', 'left', '', 'nowrap' ) .
-        html_tag( 'td', '&nbsp;' . htmlspecialchars($row['email']) . '&nbsp;', 'left', '', 'nowrap' ) .
-        html_tag( 'td', '&nbsp;' . htmlspecialchars($row['label']) . '&nbsp;', 'left', '', 'nowrap' );
+        html_tag( 'td', '&nbsp;' . sm_encode_html_special_chars($row['name']) . '&nbsp;', 'left', '', 'nowrap' ) .
+        html_tag( 'td', '&nbsp;' . sm_encode_html_special_chars($row['email']) . '&nbsp;', 'left', '', 'nowrap' ) .
+        html_tag( 'td', '&nbsp;' . sm_encode_html_special_chars($row['label']) . '&nbsp;', 'left', '', 'nowrap' );
             }
 
          if ($includesource) {
