@@ -5,9 +5,9 @@
  *
  * Manage personal address book.
  *
- * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: addressbook.php 13549 2009-04-15 22:00:49Z jervfors $
+ * @version $Id: addressbook.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  * @subpackage addressbook
  */
@@ -31,6 +31,9 @@ require_once(SM_PATH . 'functions/html.php');
 require_once(SM_PATH . 'functions/forms.php');
 
 /** lets get the global vars we may need */
+if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_POST)) {
+    $submitted_token = '';
+}
 sqgetGlobalVar('key',       $key,           SQ_COOKIE);
 
 sqgetGlobalVar('username',  $username,      SQ_SESSION);
@@ -45,7 +48,7 @@ sqgetGlobalVar('deladdr',    $deladdr,    SQ_POST);
 sqgetGlobalVar('compose_to', $compose_to, SQ_POST);
 sqgetGlobalVar('sel',        $sel,        SQ_POST);
 // renumber $sel array
-if (!empty($sel)) $sel = array_merge($sel);
+if (!empty($sel)) $sel = array_merge($sel, array());
 sqgetGlobalVar('oldnick',    $oldnick,    SQ_POST);
 sqgetGlobalVar('backend',    $backend,    SQ_POST);
 sqgetGlobalVar('doedit',     $doedit,     SQ_POST);
@@ -180,6 +183,9 @@ $form_url = 'addressbook.php';
 /* Handle user's actions */
 if(sqgetGlobalVar('REQUEST_METHOD', $req_method, SQ_SERVER) && $req_method == 'POST') {
 
+    // first, validate security token
+    sm_validate_security_token($submitted_token, -1, TRUE);
+
     /**************************************************
      * Add new address                                *
      **************************************************/
@@ -194,7 +200,7 @@ if(sqgetGlobalVar('REQUEST_METHOD', $req_method, SQ_SERVER) && $req_method == 'P
         if (!$r) {
             /* Remove backend name from error string */
             $errstr = $abook->error;
-            $errstr = ereg_replace('^\[.*\] *', '', $errstr);
+            $errstr = preg_replace('/^\[.*\] */', '', $errstr);
 
             $formerror = $errstr;
             $showaddrlist = false;
@@ -313,7 +319,7 @@ if(sqgetGlobalVar('REQUEST_METHOD', $req_method, SQ_SERVER) && $req_method == 'P
                         $olddata = $abook->lookup($enick, $ebackend);
 
                         /* Display the "new address" form */
-                        echo addForm($form_url, 'post').
+                        echo addForm($form_url, 'post', '', '', '', '', TRUE).
                             html_tag( 'table',
                                     html_tag( 'tr',
                                         html_tag( 'td',
@@ -339,13 +345,13 @@ if(sqgetGlobalVar('REQUEST_METHOD', $req_method, SQ_SERVER) && $req_method == 'P
                                  html_tag( 'tr',
                                      html_tag( 'td',
                                                "\n". '<strong><font color="' . $color[2] .
-                                               '">' . _("ERROR") . ': ' . htmlspecialchars($abook->error) . '</font></strong>' ."\n",
+                                               '">' . _("ERROR") . ': ' . sm_encode_html_special_chars($abook->error) . '</font></strong>' ."\n",
                                                'center' )
                                            ),
                                        'center', '', 'width="100%"' );
 
                         /* Display the "new address" form again */
-                        echo addForm($form_url, 'post').
+                        echo addForm($form_url, 'post', '', '', '', '', TRUE).
                             html_tag( 'table',
                                 html_tag( 'tr',
                                     html_tag( 'td',
@@ -394,7 +400,7 @@ if (!empty($formerror)) {
             html_tag( 'tr',
                 html_tag( 'td',
                     "\n". '<br /><strong><font color="' . $color[2] .
-                    '">' . _("ERROR") . ': ' . htmlspecialchars($formerror) . '</font></strong>' ."\n",
+                    '">' . _("ERROR") . ': ' . sm_encode_html_special_chars($formerror) . '</font></strong>' ."\n",
                     'center' )
                 ),
             'center', '', 'width="100%"' );
@@ -406,7 +412,7 @@ if ($showaddrlist) {
     /* Get and sort address list */
     $alist = $abook->list_addr();
     if(!is_array($alist)) {
-        $abook->error = htmlspecialchars($abook->error);
+        $abook->error = sm_encode_html_special_chars($abook->error);
         plain_error_message($abook->error, $color);
         exit;
     }
@@ -426,7 +432,7 @@ if ($showaddrlist) {
 
     /* List addresses */
     if (count($alist) > 0) {
-        echo addForm($form_url, 'post', 'address_book_form');
+        echo addForm($form_url, 'post', 'address_book_form', '', '', '', TRUE);
         if ($abook->add_extra_field) {
             $abook_fields = 6;
         } else {
@@ -516,8 +522,8 @@ if ($showaddrlist) {
                             '&nbsp;' ,
                             'center', '', 'valign="top" width="1%"' );
                 }
-                echo html_tag( 'td', '&nbsp;<label for="' . $row['backend'] . '_' . urlencode($row['nickname']) . '">' . htmlspecialchars($row['nickname']) . '</label>&nbsp;', 'left', '', 'valign="top" width="10%" nowrap' ) . 
-                    html_tag( 'td', '&nbsp;<label for="' . $row['backend'] . '_' . urlencode($row['nickname']) . '">' . htmlspecialchars($row['lastname']) . ' ' . htmlspecialchars($row['firstname']) . '</label>&nbsp;', 'left', '', 'valign="top" width="10%" nowrap' ) .
+                echo html_tag( 'td', '&nbsp;<label for="' . $row['backend'] . '_' . urlencode($row['nickname']) . '">' . sm_encode_html_special_chars($row['nickname']) . '</label>&nbsp;', 'left', '', 'valign="top" width="10%" nowrap' ) . 
+                    html_tag( 'td', '&nbsp;<label for="' . $row['backend'] . '_' . urlencode($row['nickname']) . '">' . sm_encode_html_special_chars($row['lastname']) . ' ' . sm_encode_html_special_chars($row['firstname']) . '</label>&nbsp;', 'left', '', 'valign="top" width="10%" nowrap' ) .
                     html_tag( 'td', '', 'left', '', 'valign="top" width="10%" nowrap' ) . '&nbsp;';
             } else {
                 echo html_tag( 'tr', '', '', $tr_bgcolor);
@@ -532,16 +538,16 @@ if ($showaddrlist) {
                             '&nbsp;' ,
                             'center', '', 'valign="top" width="1%"' );
                 }
-                echo html_tag( 'td', '&nbsp;<label for="' . $row['backend'] . '_' . urlencode($row['nickname']) . '">' . htmlspecialchars($row['nickname']) . '</label>&nbsp;', 'left', '', 'valign="top" width="10%" nowrap' ) .
-                    html_tag( 'td', '&nbsp;<label for="' . $row['backend'] . '_' . urlencode($row['nickname']) . '">' . htmlspecialchars($row['name']) . '</label>&nbsp;', 'left', '', 'valign="top" width="10%" nowrap' ) .
+                echo html_tag( 'td', '&nbsp;<label for="' . $row['backend'] . '_' . urlencode($row['nickname']) . '">' . sm_encode_html_special_chars($row['nickname']) . '</label>&nbsp;', 'left', '', 'valign="top" width="10%" nowrap' ) .
+                    html_tag( 'td', '&nbsp;<label for="' . $row['backend'] . '_' . urlencode($row['nickname']) . '">' . sm_encode_html_special_chars($row['name']) . '</label>&nbsp;', 'left', '', 'valign="top" width="10%" nowrap' ) .
                     html_tag( 'td', '', 'left', '', 'valign="top" width="10%" nowrap' ) . '&nbsp;';
             }
             $email = $abook->full_address($row);
             echo addHidden($row['backend'] . ':' . $row['nickname'], rawurlencode($email))
                . makeComposeLink('src/compose.php?send_to='.rawurlencode($email),
-                    htmlspecialchars($row['email'])).
+                    sm_encode_html_special_chars($row['email'])).
                 '&nbsp;</td>'."\n".
-                html_tag( 'td', '&nbsp;<label for="' . $row['backend'] . '_' . urlencode($row['nickname']) . '">' . htmlspecialchars($row['label']) . '</label>&nbsp;', 'left', '', 'valign="top" width="10%"' );
+                html_tag( 'td', '&nbsp;<label for="' . $row['backend'] . '_' . urlencode($row['nickname']) . '">' . sm_encode_html_special_chars($row['label']) . '</label>&nbsp;', 'left', '', 'valign="top" width="10%"' );
 
             // add extra column if third party backend needs it
             if ($abook->add_extra_field) {
@@ -573,7 +579,7 @@ if ($showaddrlist) {
 
 /* Display the "new address" form */
 echo '<a name="AddAddress"></a>' . "\n" .
-    addForm($form_url, 'post', 'f_add').
+    addForm($form_url, 'post', 'f_add', '', '', '', TRUE).
     html_tag( 'table',  
         html_tag( 'tr',
             html_tag( 'td', "\n". '<strong>' . sprintf(_("Add to %s"), $abook->localbackendname) . '</strong>' . "\n",
