@@ -7,9 +7,9 @@
  * scripts which do most of the work. Also handles the Special
  * Folders.
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folders.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: folders.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package squirrelmail
  */
 
@@ -91,7 +91,8 @@ if ( isset($success) && $success ) {
 
 echo "\n<br />";
 
-$imapConnection = sqimap_login ($username, $key, $imapServerAddress, $imapPort, 0);
+global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login ($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
 
 // force retrieval of a non cached folderlist
 $boxes = sqimap_mailbox_list($imapConnection,true);
