@@ -6,9 +6,9 @@
  * Deletes folders from the IMAP server. 
  * Called from the folders.php
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folders_delete.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: folders_delete.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package squirrelmail
  */
 
@@ -89,9 +89,10 @@ if( !sqgetGlobalVar('confirmed', $tmp, SQ_POST) ) {
 }
 
 // first, validate security token
-sm_validate_security_token($submitted_token, 3600, TRUE);
+sm_validate_security_token($submitted_token, -1, TRUE);
 
-$imap_stream = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+global $imap_stream_options; // in case not defined in config
+$imap_stream = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
 
 $boxes = sqimap_mailbox_list ($imap_stream);
 $numboxes = count($boxes);
