@@ -6,9 +6,9 @@
  * Does the actual renaming of files on the IMAP server.
  * Called from the folders.php
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folders_rename_do.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: folders_rename_do.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package squirrelmail
  */
 
@@ -41,7 +41,7 @@ if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_POST)) {
 /* end globals */
 
 // first, validate security token
-sm_validate_security_token($submitted_token, 3600, TRUE);
+sm_validate_security_token($submitted_token, -1, TRUE);
 
 $new_name = trim($new_name);
 
@@ -61,7 +61,8 @@ $new_name = imap_utf7_encode_local($new_name);
 
 if ($old_name <> $new_name) {
 
-    $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+    global $imap_stream_options; // in case not defined in config
+    $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
 
     if (strpos($orig, $delimiter)) {
         $old_dir = substr($orig, 0, strrpos($orig, $delimiter));
