@@ -6,9 +6,9 @@
  * Subscribe and unsubcribe from folders. 
  * Called from folders.php
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folders_subscribe.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: folders_subscribe.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package squirrelmail
  */
 
@@ -39,7 +39,7 @@ if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_POST)) {
 /* end globals */
 
 // first, validate security token
-sm_validate_security_token($submitted_token, 3600, TRUE);
+sm_validate_security_token($submitted_token, -1, TRUE);
 
 $location = get_location();
 
@@ -49,7 +49,8 @@ if (!isset($mailbox) || !isset($mailbox[0]) || $mailbox[0] == '') {
     exit(0);
 }
 
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
 
 if ($method == 'sub') {
     if($no_list_for_subscribe && $imap_server_type == 'cyrus') {
