@@ -6,9 +6,9 @@
  * This is the code for the left bar. The left bar shows the folders
  * available, and has cookie information.
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: left_main.php 13946 2010-06-21 00:43:54Z pdontthink $
+ * @version $Id: left_main.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package squirrelmail
  */
 
@@ -21,6 +21,8 @@ define('PAGE_NAME', 'left_main');
  */
 define('SM_PATH','../');
 
+$script_libs = array();
+
 /* SquirrelMail required files. */
 require_once(SM_PATH . 'include/validate.php');
 require_once(SM_PATH . 'functions/imap.php');
@@ -103,7 +105,7 @@ function formatMailboxName($imapConnection, $box_array) {
         if (($numMessages > 0) or ($box_array['parent'] == 1)) {
             $urlMailbox = urlencode($real_box);
             $line .= "\n<small>\n" .
-                    '&nbsp;&nbsp;(<a href="empty_trash.php" style="text-decoration:none">'._("Purge").'</a>)' .
+                    '&nbsp;&nbsp;(<a href="empty_trash.php?smtoken=' . sm_generate_security_token() . '" style="text-decoration:none">'._("Purge").'</a>)' .
                     '</small>';
         }
     }
@@ -307,20 +309,29 @@ header('Cache-Control: no-cache, no-store, must-revalidate');
 header('Pragma: no-cache');
 header('Expires: Sat, 1 Jan 2000 00:00:00 GMT');
 
-// open a connection on the imap port (143)
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 10); // the 10 is to hide the output
+// open a connection to the IMAP server
+global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 10, $imap_stream_options); // the 10 is to hide the output
 
 /**
  * Using stristr since older preferences may contain "None" and "none".
  */
+$xtra = '';
 if (isset($left_refresh) && ($left_refresh != '') &&
     !stristr($left_refresh, 'none')){
-    $xtra =  "\n<meta http-equiv=\"REFRESH\" content=\"$left_refresh;URL=left_main.php\">\n";
-} else {
-    $xtra = '';
+    if ($javascript_on
+     && ($check_mail_mechanism === 'basic' || $check_mail_mechanism === 'advanced')) {
+        $script_libs[] = SM_SCRIPT_LIB_REMOTE_REQUEST;
+        $script_libs[] = SM_SCRIPT_LIB_RELOAD_PAGE;
+        // NB: we could use $script_libs instead of $xtra - they both do the same thing for adding free-form extra script tags
+        // FIXME: the "advanced" version of the JavaScript check mail feature could be triggered by browser detection (brief testing shows that at least IE 8 doesn't like the advanced version).... but for now, just let admin decide in system settings
+        $xtra = "\n<script language=\"JavaScript\" type=\"text/javascript\">\n<!--\nvar base_uri = '" . $base_uri . "';\nvar reload_interval = " . $left_refresh . ";\nvar use_advanced_page_reload = " . ($check_mail_mechanism === 'advanced' ? "true;\n" : "false;\n") . "// -->\n</script>\n";
+    } else {
+        $xtra =  "\n<meta http-equiv=\"REFRESH\" content=\"$left_refresh;URL=left_main.php\">\n";
+    }
 }
 
-displayHtmlHeader( $org_title, $xtra );
+displayHtmlHeader( $org_title, $xtra, TRUE, $script_libs );
 
 /* If requested and not yet complete, attempt to autocreate folders. */
 if ($auto_create_special && !$auto_create_done) {
