@@ -6,9 +6,9 @@
  * This a simple login screen. Some housekeeping is done to clean
  * cookies and find language.
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: login.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: login.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  */
 
@@ -110,11 +110,15 @@ if (!empty($sel)) {
         sqsession_register($sep, 'session_expired_post');
 }
 
+// Disable Browser Caching
+//
+header('Cache-Control: no-cache, no-store, must-revalidate');
 header('Pragma: no-cache');
+header('Expires: Sat, 1 Jan 2000 00:00:00 GMT');
 
 do_hook('login_cookie');
 
-$loginname_value = (sqGetGlobalVar('loginname', $loginname) ? htmlspecialchars($loginname) : '');
+$loginname_value = (sqGetGlobalVar('loginname', $loginname) ? sm_encode_html_special_chars($loginname) : '');
 
 /* Output the javascript onload function. */
 
