@@ -5,9 +5,9 @@
  *
  * Displays message highlighting options
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: options_highlight.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: options_highlight.php 14422 2014-01-01 20:59:43Z pdontthink $
  * @package squirrelmail
  * @subpackage prefs
  */
@@ -64,7 +64,7 @@ if (isset($theid) && ($action == 'delete') ||
                      ($action == 'down')) {
 
     // security check
-    sm_validate_security_token($submitted_token, 3600, TRUE);
+    sm_validate_security_token($submitted_token, -1, TRUE);
 
     $new_rules = array();
     switch($action) {
@@ -101,7 +101,7 @@ if (isset($theid) && ($action == 'delete') ||
 } else if ($action == 'save') {
 
     // security check
-    sm_validate_security_token($submitted_token, 3600, TRUE);
+    sm_validate_security_token($submitted_token, -1, TRUE);
 
     if ($color_type == 1) $newcolor = $newcolor_choose;
     elseif ($color_type == 2) $newcolor = $newcolor_input;
@@ -141,6 +141,7 @@ echo '<center>[<a href="options_highlight.php?action=add">' . _("New") . '</a>]'
 $mhl_count = count($message_highlight_list);
 if ($mhl_count > 0) {
     echo html_tag( 'table', '', 'center', '', 'width="80%" border="0" cellpadding="3" cellspacing="0"' ) . "\n";
+    $token = sm_generate_security_token();
     for ($i=0; $i < $mhl_count; $i++) {
         $match_type = '';
         switch ($message_highlight_list[$i]['match_type'] ) {
@@ -163,13 +164,13 @@ if ($mhl_count > 0) {
 
         $links = '<small>[<a href="options_highlight.php?action=edit&amp;theid=' . $i . '">' .
                  _("Edit") .
-                 '</a>]&nbsp;[<a href="options_highlight.php?action=delete&amp;smtoken=' . sm_generate_security_token() . '&amp;theid='.  $i . '">' .
+                 '</a>]&nbsp;[<a href="options_highlight.php?action=delete&amp;smtoken=' . $token . '&amp;theid='.  $i . '">' .
                  _("Delete");
         if($i > 0) {
-            $links .= '</a>]&nbsp;[<a href="options_highlight.php?action=up&amp;smtoken=' . sm_generate_security_token() . '&amp;theid='.  $i . '">' .  _("Up");
+            $links .= '</a>]&nbsp;[<a href="options_highlight.php?action=up&amp;smtoken=' . $token . '&amp;theid='.  $i . '">' .  _("Up");
         }
         if($i+1 < $mhl_count) {
-            $links .= '</a>]&nbsp;[<a href="options_highlight.php?action=down&amp;smtoken=' . sm_generate_security_token() . '&amp;theid='.  $i . '">' .  _("Down");
+            $links .= '</a>]&nbsp;[<a href="options_highlight.php?action=down&amp;smtoken=' . $token . '&amp;theid='.  $i . '">' .  _("Down");
         }
         $links .= '</a>]</small>';
 
@@ -178,11 +179,11 @@ if ($mhl_count > 0) {
                         $links,
                     'left', $color[4], 'width="20%" nowrap' ) .
                     html_tag( 'td',
-                        htmlspecialchars($message_highlight_list[$i]['name']) ,
+                        sm_encode_html_special_chars($message_highlight_list[$i]['name']) ,
                     'left' ) .
                     html_tag( 'td',
                         $match_type . ' = ' .
-                        htmlspecialchars($message_highlight_list[$i]['value']) ,
+                        sm_encode_html_special_chars($message_highlight_list[$i]['value']) ,
                     'left' ) ,
                 '', '#' . $message_highlight_list[$i]['color'] ) . "\n";
     }
