@@ -8,9 +8,9 @@
  *
  * - this is the page that does all the work, really.
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: printer_friendly_bottom.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: printer_friendly_bottom.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package squirrelmail
  */
 
@@ -42,7 +42,8 @@ if (! sqgetGlobalVar('passed_ent_id', $passed_ent_id, SQ_GET) ||
 /* end globals */
 
 $pf_cleandisplay = getPref($data_dir, $username, 'pf_cleandisplay', false);
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
 $mbx_response = sqimap_mailbox_select($imapConnection, $mailbox);
 if (isset($messages[$mbx_response['UIDVALIDITY']][$passed_id])) {
     $message = $messages[$mbx_response['UIDVALIDITY']][$passed_id];
@@ -131,7 +132,7 @@ echo '<body text="#000000" bgcolor="#FFFFFF" link="#000000" vlink="#000000" alin
      ) . "\n" .
      html_tag( 'tr',
          html_tag( 'td', _("Date").':&nbsp;', 'left' ) .
-         html_tag( 'td', htmlspecialchars($date), 'left' )
+         html_tag( 'td', sm_encode_html_special_chars($date), 'left' )
      ) . "\n" .
      html_tag( 'tr',
          html_tag( 'td', _("To").':&nbsp;', 'left','','valign="top"' ) .
@@ -280,7 +281,7 @@ function pf_show_attachments($message, $exclude_id, $mailbox, $id) {
             html_tag( 'td',show_readable_size($header->size), 'left') .
             '</tr><tr>' .
             html_tag( 'td',_("Type:"), 'right') .
-            html_tag( 'td',htmlspecialchars($type0).'/'.htmlspecialchars($type1), 'left') . 
+            html_tag( 'td',sm_encode_html_special_chars($type0).'/'.sm_encode_html_special_chars($type1), 'left') . 
             '</tr>';
         if (! empty($description)) {
             $attachments .= $description;
