@@ -6,9 +6,9 @@
  * This file is used for reading the msgs array and displaying
  * the resulting emails in the right frame.
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: read_body.php 13906 2010-02-13 23:06:30Z pdontthink $
+ * @version $Id: read_body.php 14450 2014-03-17 22:53:14Z pdontthink $
  * @package squirrelmail
  */
 
@@ -458,7 +458,7 @@ function formatEnvheader($mailbox, $passed_id, $passed_ent_id, $message,
     $env[_("Cc")] = formatRecipientString($header->cc, "cc");
     $env[_("Bcc")] = formatRecipientString($header->bcc, "bcc");
     if ($default_use_priority) {
-        $env[_("Priority")] = htmlspecialchars(getPriorityStr($header->priority));
+        $env[_("Priority")] = sm_encode_html_special_chars(getPriorityStr($header->priority));
     }
     if ($show_xmailer_default) {
         $env[_("Mailer")] = decodeHeader($header->xmailer);
@@ -520,7 +520,7 @@ function formatEnvheader($mailbox, $passed_id, $passed_ent_id, $message,
     echo '</table>';
 }
 
-function formatMenubar($mailbox, $passed_id, $passed_ent_id, $message, $mbx_response) {
+function formatMenuBar($mailbox, $passed_id, $passed_ent_id, $message, $mbx_response) {
     global $base_uri, $draft_folder, $where, $what, $color, $sort,
            $startMessage, $PHP_SELF, $save_as_draft,
            $enable_forward_as_attachment;
@@ -665,8 +665,8 @@ function formatMenubar($mailbox, $passed_id, $passed_ent_id, $message, $mbx_resp
     $s .= $topbar_delimiter;
     $s .= makeComposeLink($comp_action_uri, _("Reply All"));
     $s .= '</small></td></tr></table>';
-    $ret = concat_hook_function('read_body_menu_top', $s);
-    if($ret != '') {
+    $ret = do_hook_function('read_body_menu_top', $s);
+    if(!is_null($ret)) {
         $s = $ret;
     }
     echo $s;
@@ -771,7 +771,8 @@ if ( sqgetGlobalVar('startMessage', $temp) ) {
 /* end of get globals */
 global $uid_support, $sqimap_capabilities;
 
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
 $mbx_response   = sqimap_mailbox_select($imapConnection, $mailbox, false, false, true);
 
 
@@ -896,11 +897,13 @@ if ($attachmentsdisplay) {
    echo '       <table width="100%" cellpadding="0" cellspacing="0" align="center" border="0" bgcolor="'.$color[4].'">';
    echo '        <tr>' . html_tag( 'td', '', 'left', $color[9] );
    echo '           <b>' . _("Attachments") . ':</b>';
+   $hook_args = array($message, $mailbox, $passed_id, $passed_ent_id);
+   echo concat_hook_function('attachments_top', $hook_args);
    echo '        </td></tr>';
    echo '        <tr><td>';
-   echo '          <table width="100%" cellpadding="2" cellspacing="2" align="center"'.' border="0" bgcolor="'.$color[0].'"><tr><td>';
+   echo '          <table width="100%" cellpadding="2" cellspacing="2" align="center"'.' border="0" bgcolor="'.$color[0].'">';
    echo              $attachmentsdisplay;
-   echo '          </td></tr></table>';
+   echo '          </table>';
    echo '       </td></tr></table>';
    echo '    </td></tr></table>';
    echo '  </td></tr>';
