@@ -5,9 +5,9 @@
  *
  * Derived from webmail.php by Ralf Kraudelt <kraude@wiwi.uni-rostock.de>
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: redirect.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: redirect.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package squirrelmail
  */
 
@@ -30,7 +30,11 @@ require_once(SM_PATH . 'functions/plugin.php');
 require_once(SM_PATH . 'functions/constants.php');
 require_once(SM_PATH . 'functions/page_header.php');
 
+// Disable Browser Caching
+//
+header('Cache-Control: no-cache, no-store, must-revalidate');
 header('Pragma: no-cache');
+header('Expires: Sat, 1 Jan 2000 00:00:00 GMT');
 $location = get_location();
 
 sqsession_is_active();
@@ -98,7 +102,8 @@ if (!sqsession_is_registered('user_is_logged_in')) {
         $login_username = strtolower($login_username);
     }
 
-    $imapConnection = sqimap_login($login_username, $key, $imapServerAddress, $imapPort, 0);
+    global $imap_stream_options; // in case not defined in config
+    $imapConnection = sqimap_login($login_username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
 
     $sqimap_capabilities = sqimap_capability($imapConnection);
     sqsession_register($sqimap_capabilities, 'sqimap_capabilities');
@@ -110,7 +115,10 @@ if (!sqsession_is_registered('user_is_logged_in')) {
     $username = $login_username;
     sqsession_register ($username, 'username');
     sqsetcookie('key', $key, 0, $base_uri);
+
+    $is_login_verified_hook = TRUE;
     do_hook ('login_verified');
+    $is_login_verified_hook = FALSE;
 
 }
 
