@@ -6,9 +6,9 @@
  * This is where the mailboxes are listed. This controls most of what
  * goes on in SquirrelMail.
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: right_main.php 13946 2010-06-21 00:43:54Z pdontthink $
+ * @version $Id: right_main.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package squirrelmail
  */
 
@@ -95,7 +95,8 @@ if ( !sqgetGlobalVar('composenew', $composenew, SQ_GET) ) {
 
 /* Open a connection on the imap port (143) */
 
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
 
 if (isset($PG_SHOWALL)) {
     if ($PG_SHOWALL) {
@@ -174,7 +175,7 @@ if ($composenew) {
 
 do_hook('right_main_after_header');
 if (isset($note)) {
-    echo html_tag( 'div', '<b>' . htmlspecialchars($note) .'</b>', 'center' ) . "<br />\n";
+    echo html_tag( 'div', '<b>' . sm_encode_html_special_chars($note) .'</b>', 'center' ) . "<br />\n";
 }
 
 if ( sqgetGlobalVar('just_logged_in', $just_logged_in, SQ_SESSION) ) {
