@@ -5,9 +5,9 @@
  *
  * IMAP search page
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: search.php 13969 2010-07-21 19:21:39Z pdontthink $
+ * @version $Id: search.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package squirrelmail
  * @subpackage search
  */
@@ -238,15 +238,17 @@ function printSearchMessages($msgs,$mailbox, $cnt, $imapConnection, $where, $wha
             $showbox = imap_utf7_decode_local($mailbox);
         }
         echo html_tag( 'div', '<b><big>' . _("Folder:") . ' '.
-            htmlspecialchars($showbox) .'</big></b>','center') . "\n";
+            sm_encode_html_special_chars($showbox) .'</big></b>','center') . "\n";
 
         $msg_cnt_str = get_msgcnt_str(1, $cnt, $cnt);
         $toggle_all = get_selectall_link(1, $sort);
 
+        do_hook('search_index_before');
+
         $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
         $form_name = "FormMsgs" . $safe_name;
         echo '<form name="' . $form_name . '" method="post" action="move_messages.php">' ."\n" .
-             '<input type="hidden" name="mailbox" value="'.htmlspecialchars($mailbox).'">' . "\n" .
+             '<input type="hidden" name="mailbox" value="'.sm_encode_html_special_chars($mailbox).'">' . "\n" .
              '<input type="hidden" name="startMessage" value="1">' . "\n" .
              addHidden('smtoken', sm_generate_security_token()) . "\n";
 
@@ -285,7 +287,8 @@ $perbox_count = array ();
 $recent_count = getPref($data_dir, $username, 'search_memory', 0);
 
 /*  get mailbox names  */
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
 $boxes = sqimap_mailbox_list($imapConnection);
 
 /*  set current mailbox to INBOX if none was selected or if page
@@ -319,7 +322,7 @@ if (empty($submit) && !empty($what)) {
 
 // need to verify security token if user wants to do anything
 if (!empty($submit)) {
-    sm_validate_security_token($submitted_token, 3600, TRUE);
+    sm_validate_security_token($submitted_token, -1, TRUE);
 }
 
 if ($submit == _("Search") && !empty($what)) {
@@ -371,9 +374,9 @@ if ($saved_count > 0) {
         } else {
             echo html_tag( 'tr', '', '', $color[4] );
         }
-        echo html_tag( 'td', htmlspecialchars(imap_utf7_decode_local($saved_attributes['saved_folder'][$i + 1])), 'left', '', 'width="35%"' )
-        . html_tag( 'td', htmlspecialchars($saved_attributes['saved_what'][$i + 1]), 'left' )
-        . html_tag( 'td', htmlspecialchars($saved_attributes['saved_where'][$i + 1]), 'center' )
+        echo html_tag( 'td', sm_encode_html_special_chars(imap_utf7_decode_local($saved_attributes['saved_folder'][$i + 1])), 'left', '', 'width="35%"' )
+        . html_tag( 'td', sm_encode_html_special_chars($saved_attributes['saved_what'][$i + 1]), 'left' )
+        . html_tag( 'td', sm_encode_html_special_chars($saved_attributes['saved_where'][$i + 1]), 'center' )
         . html_tag( 'td', '', 'right' )
         .   '<a href="search.php'
         .     '?mailbox=' . urlencode($saved_attributes['saved_folder'][$i + 1])
@@ -420,9 +423,9 @@ if ($recent_count > 0) {
             }
             if (isset($attributes['search_what'][$i]) &&
                 !empty($attributes['search_what'][$i])) {
-            echo html_tag( 'td', htmlspecialchars(imap_utf7_decode_local($attributes['search_folder'][$i])), 'left', '', 'width="35%"' )
-               . html_tag( 'td', htmlspecialchars($attributes['search_what'][$i]), 'left' )
-               . html_tag( 'td', htmlspecialchars($attributes['search_where'][$i]), 'center' )
+            echo html_tag( 'td', sm_encode_html_special_chars(imap_utf7_decode_local($attributes['search_folder'][$i])), 'left', '', 'width="35%"' )
+               . html_tag( 'td', sm_encode_html_special_chars($attributes['search_what'][$i]), 'left' )
+               . html_tag( 'td', sm_encode_html_special_chars($attributes['search_where'][$i]), 'center' )
                . html_tag( 'td', '', 'right' )
                .   "<a href=\"search.php?count=$i&amp;submit=save&amp;smtoken=" . sm_generate_security_token() . '">'
                .     _("save")
