@@ -5,9 +5,9 @@
  *
  * This is the code to view the message header.
  *
- * @copyright 1999-2010 The SquirrelMail Project Team
+ * @copyright 1999-2014 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: view_header.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: view_header.php 14436 2014-01-21 21:30:59Z pdontthink $
  * @package squirrelmail
  */
 
@@ -46,7 +46,7 @@ function parse_viewheader($imapConnection,$id, $passed_ent_id) {
     $cnum = 0;
 
     for ($i=1; $i < count($read); $i++) {
-        $line = htmlspecialchars($read[$i]);
+        $line = sm_encode_html_special_chars($read[$i]);
         switch (true) {
             case (preg_match('/^&gt;/i', $line)):
                 $second[$i] = $line;
@@ -133,8 +133,9 @@ sqgetGlobalVar('username',   $username,     SQ_SESSION);
 sqgetGlobalVar('onetimepad', $onetimepad,   SQ_SESSION);
 sqgetGlobalVar('delimiter',  $delimiter,    SQ_SESSION);
 
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, 
-                               $imapPort, 0);
+global $imap_stream_options; // in case not defined in config
+$imapConnection = sqimap_login($username, $key, $imapServerAddress,
+                               $imapPort, 0, $imap_stream_options);
 $mbx_response = sqimap_mailbox_select($imapConnection, $mailbox, false, false, true);
 
 $header = parse_viewheader($imapConnection,$passed_id, $passed_ent_id); 
